@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                          CDF software distribution configuration.
 *
@@ -63,13 +68,7 @@
 #define SUPPORT_HUFF64          1
 #define SUPPORT_AHUFF64         1
 #define SUPPORT_GZIP64          1
-/*
-#if defined(dos)
-#  define SUPPORT_ZLIB64        0
-#else
-#  define SUPPORT_ZLIB64        1
-#endif
-*/
+
 /******************************************************************************
 * Supported checksums.  1 = yes, 0 = no.
 ******************************************************************************/
@@ -143,7 +142,7 @@
 /*****************************************************************************
 * Blocking factors.
 *****************************************************************************/
-#if defined(win32) && (_FILE_OFFSET_BITS == 64)
+#if defined(win32)
 
 #  define MIN_BLOCKING_BYTES_standard     512
 #  define MIN_BLOCKING_RECS_standard      1
@@ -151,17 +150,28 @@
 #  define MIN_BLOCKING_BYTES_sparse       2048
 #  define MIN_BLOCKING_RECS_sparse        1
 
-#  define MIN_BLOCKING_BYTES_compressed   5120
+#  define MIN_BLOCKING_BYTES_compressed   32768
 #  define MIN_BLOCKING_RECS_compressed    1
 #else
-#  define MIN_BLOCKING_BYTES_standard     512
-#  define MIN_BLOCKING_RECS_standard      1
+#  if defined(linux)
+#    define MIN_BLOCKING_BYTES_standard     8192
+#    define MIN_BLOCKING_RECS_standard      1
 
-#  define MIN_BLOCKING_BYTES_sparse       2048
-#  define MIN_BLOCKING_RECS_sparse        1
+#    define MIN_BLOCKING_BYTES_sparse       16384
+#    define MIN_BLOCKING_RECS_sparse        1
 
-#  define MIN_BLOCKING_BYTES_compressed   5120
-#  define MIN_BLOCKING_RECS_compressed    1
+#    define MIN_BLOCKING_BYTES_compressed   32768
+#    define MIN_BLOCKING_RECS_compressed    1
+#  else
+#    define MIN_BLOCKING_BYTES_standard     1024
+#    define MIN_BLOCKING_RECS_standard      1
+
+#    define MIN_BLOCKING_BYTES_sparse       4096
+#    define MIN_BLOCKING_RECS_sparse        1
+
+#    define MIN_BLOCKING_BYTES_compressed   32768
+#    define MIN_BLOCKING_RECS_compressed    1
+#  endif
 #endif
 /*****************************************************************************
 * Should trailing blanks be automatically stripped from CDF pathnames when
@@ -186,10 +196,10 @@
 
 /*****************************************************************************
 * Should the default encoding for CDFs created with the Internal Interface be
-* HOST_ENCODING (the alternative is NETWORK_ENCODING)?
+* HOST_ENCODING (the alternative is IBMPC_ENCODING)?
 *****************************************************************************/
 
-#define DEFAULT_TO_HOST_ENCODING        TRUE    /* TRUE = yes, FALSE = no. */
+#define DEFAULT_TO_HOST_ENCODING        TRUE     /* TRUE = yes, FALSE = no. */
 
 /*****************************************************************************
 * Should the default majority for CDFs created with the Internal Interface be
@@ -231,21 +241,22 @@
 * The default pad values for each data type.
 *****************************************************************************/
 
-#define DEFAULT_BYTE_PADVALUE           0
-#define DEFAULT_INT1_PADVALUE           0
-#define DEFAULT_UINT1_PADVALUE          0
-#define DEFAULT_INT2_PADVALUE           0
-#define DEFAULT_UINT2_PADVALUE          0
-#define DEFAULT_INT4_PADVALUE           0
-#define DEFAULT_INT8_PADVALUE           -9223372036854775807LL-1
-#define DEFAULT_UINT4_PADVALUE          0
-#define DEFAULT_REAL4_PADVALUE          0.0
-#define DEFAULT_FLOAT_PADVALUE          0.0
-#define DEFAULT_REAL8_PADVALUE          0.0
-#define DEFAULT_DOUBLE_PADVALUE         0.0
+#define DEFAULT_BYTE_PADVALUE           -127
+#define DEFAULT_INT1_PADVALUE           -127
+#define DEFAULT_UINT1_PADVALUE          254
+#define DEFAULT_INT2_PADVALUE           -32767
+#define DEFAULT_UINT2_PADVALUE          65534
+#define DEFAULT_INT4_PADVALUE           -2147483647
+#define DEFAULT_INT8_PADVALUE           -9223372036854775807LL
+#define DEFAULT_UINT4_PADVALUE          4294967294u
+#define DEFAULT_REAL4_PADVALUE          -1.0E30
+#define DEFAULT_FLOAT_PADVALUE          -1.0E30
+#define DEFAULT_REAL8_PADVALUE          -1.0E30
+#define DEFAULT_DOUBLE_PADVALUE         -1.0E30
 #define DEFAULT_CHAR_PADVALUE           ' '
 #define DEFAULT_UCHAR_PADVALUE          ' '
 #define DEFAULT_EPOCH_PADVALUE          0.0
+#define DEFAULT_EPOCH16_PADVALUE        0.0
 #define DEFAULT_TT2000_PADVALUE         -9223372036854775807LL
                                         /* 0000-01-01T00:00:00.000000000 */
 /*****************************************************************************
@@ -397,6 +408,7 @@
 #define DEFAULTlevelIRsDUMP        1            /* 1 == "brief",
 						   2 == "most",
 						   3 == "full" */
+#define DEFAULTdataIRsDUMP	   FALSE	/* data. */
 
 /******************************************************************************
 * Command line defaults for CDFcompare.
@@ -474,6 +486,7 @@
 #define DEFAULTdeleteSKT2CDF    FALSE           /* [no]delete */
 #define DEFAULTfillvalSKT2CDF   FALSE           /* [no]fillval */
 #define DEFAULTstatsSKT2CDF	FALSE		/* [no]statistics */
+#define DEFAULTwarningSKT2CDF	TRUE		/* [no]warning */
 #define DEFAULTzModeSKT2CDF     zMODEoff        /* zMODEoff = zMode/0,
 						   zMODEon1 = zMode/1,
 						   zMODEon2 = zMode/2 */
@@ -485,9 +498,9 @@
 * means `noxxxxx'.
 ******************************************************************************/
 
-#define DEFAULTshortDUMP        FALSE           /* [no]short */
 #define DEFAULTformatDUMP       TRUE            /* [no]format */
-#define DEFAULTnoheaderDUMP     FALSE           /* noheader */
+#define DEFAULTheaderDUMP       TRUE            /* [no]header */
+#define DEFAULTcol2rowDUMP      FALSE           /* col2row    */
 
 /******************************************************************************
 * Command line defaults for CDFmerge.
@@ -550,6 +563,7 @@
 
 #define DEFAULTvalidateValidate TRUE            /* [no]validate */
 #define DEFAULTdebugValidate    FALSE           /* [no]debug */
+#define DEFAULTquietValidate    TRUE            /* [no]quiet */
 
 /******************************************************************************
 * Key definitions for the toolkit program using a full-screen interface.
