@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                                    Header file for CDF library.
 *
@@ -535,7 +540,7 @@ STATICforIDL CDFstatus WriteBuffer64 PROTOARGs((
   void *buffer
 ));
 STATICforIDL CDFstatus WriteVarElems64 PROTOARGs((
-  struct VarStruct *Var, vFILE *fp, OFF_T offset, Int32 numElems, void *buffer
+  struct VarStruct *Var, vFILE *fp, OFF_T offset, OFF_T numElems, void *buffer
 ));
 STATICforIDL CDFstatus HyperRead64 PROTOARGs((
   struct CDFstruct *CDF, struct VarStruct *Var, struct rdSTRUCT *rd,
@@ -760,19 +765,9 @@ STATICforIDL CDFstatus DecompressGZIP_64 PROTOARGs((
   vFILE *srcFp, OFF_T srcOffset, CDFstatus srcError, vFILE *destFp,
   OFF_T destOffset, CDFstatus destError
 ));
-/*
-STATICforIDL CDFstatus CompressZLIB0_64 PROTOARGs((
-  vFILE *srcFp, OFF_T srcOffset, OFF_T srcSize, CDFstatus srcError,
-  vFILE *destFp, OFF_T destOffset, OFF_T *destSize, CDFstatus destError
-));
-STATICforIDL CDFstatus DecompressZLIB0_64 PROTOARGs((
-  vFILE *srcFp, OFF_T srcOffset, OFF_T iSize, CDFstatus srcError, 
-  vFILE *destFp, OFF_T destOffset, CDFstatus destError
-));
-*/
 STATICforIDL CDFstatus WriteVarValues64 PROTOARGs((
   struct CDFstruct *CDF, struct VarStruct *Var, Int32 recNum, Int32 offset,
-  Int32 nValues, void *buffer
+  OFF_T nValues, void *buffer
 ));
 STATICforIDL CDFstatus SearchForRecord64 PROTOARGs((
   struct CDFstruct *CDF, OFF_T VDRoffset, Logical zVar, Int32 recNum,
@@ -783,10 +778,10 @@ STATICforIDL CDFstatus IndexingStatistics64 PROTOARGs((
   Int32 *nEntriesP, Int32 *nAllocP, Int32 *nRecordsP, Int32 *nLevelsP
 ));
 STATICforIDL CDFstatus DefaultPadBuffer64 PROTOARGs((
-  struct CDFstruct *CDF, struct VarStruct *Var, Int32 nValues, void *buffer
+  struct CDFstruct *CDF, struct VarStruct *Var, OFF_T nValues, void *buffer
 ));                   
 STATICforIDL CDFstatus PadBuffer64 PROTOARGs((
-  struct CDFstruct *CDF, struct VarStruct *Var, Int32 nValues, void *buffer
+  struct CDFstruct *CDF, struct VarStruct *Var, OFF_T nValues, void *buffer
 ));
 STATICforIDL CDFstatus BuildPadBuffer64 PROTOARGs((
   struct CDFstruct *CDF, struct VarStruct *Var, Int32 nRecords, int *how,
@@ -797,11 +792,11 @@ STATICforIDL CDFstatus WritePadValues64 PROTOARGs((
   void *buffer
 ));
 STATICforIDL CDFstatus ReadVarElems64 PROTOARGs((
-  struct VarStruct *Var, vFILE *fp, OFF_T offset, Int32 numElems, void *buffer
+  struct VarStruct *Var, vFILE *fp, OFF_T offset, OFF_T numElems, void *buffer
 ));
 STATICforIDL CDFstatus ReadVarValues64 PROTOARGs((
   struct CDFstruct *CDF, struct VarStruct *Var, Int32 recNum, Int32 offset,
-  Int32 nValues, void *buffer
+  OFF_T nValues, void *buffer
 ));
 STATICforIDL CDFstatus PrevRecord64 PROTOARGs((
   struct CDFstruct *CDF, OFF_T VDRoffset, Logical zVar, Int32 baseRec,
