@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF				CDF Standard Interface (II) /FORTRAN.
 *
@@ -958,6 +963,33 @@ Int32     *status;              /* Out: CDF status code. */
   return;
 }
 
+/******************************************************************************
+* CDF_insert_zvar_recs.
+******************************************************************************/
+VISIBLE_PREFIX
+Fif_PREFIXa
+void
+Fif_PREFIXb
+Fif_ENTRYPOINT(cdf_insert_zvar_recs__,
+               cdf_insert_zvar_recs_,
+               cdf_insert_zvar_recs,
+               CDF_INSERT_ZVAR_RECS)
+(id, var_num, start_rec, num_recs, buffer, status)
+Int32     *id;                  /* In: CDF identifier. */
+Int32     *var_num;             /* In: zVariable number. */
+Int32     *start_rec;           /* In: zVariable's start record number. */
+Int32     *num_recs;            /* In: Number of records to insert. */
+void      *buffer;              /* In: Buffer holding the inserted data. */
+Int32     *status;              /* Out: CDF status code. */
+{
+  long startRec = (long) (*start_rec - 1);
+  *status = (Int32) CDFinsertVarRecordsByVarID (Int32ToCDFid(*id), 1,
+                                                (long) (*var_num -1),
+                                                startRec, (long) *num_recs,
+                                                buffer);
+  return;
+}
+
 /******************************************************************************
 *  CDF_get_num_rvars.
 ******************************************************************************/
