@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                                       CDF `get' operations.
 *
@@ -162,7 +167,8 @@ switch (Va->item) {
   case DATATYPE_SIZE_: {
     long dataType = va_arg (Va->ap, long);
     long *numBytes = va_arg (Va->ap, long *);
-    if (!ValidDataType((Int32)dataType)) return BAD_DATA_TYPE;
+    if (!ValidDataType((Int32)dataType) || InValidDataType((Int32)dataType))
+      return BAD_DATA_TYPE;
     *numBytes = (long) CDFelemSize (dataType);
     break;
   }
@@ -277,7 +283,7 @@ switch (Va->item) {
     long *cParms = va_arg (Va->ap, long *);     /* Compression parameters. */
     long *cPct = va_arg (Va->ap, long *);	/* Compression percentage. */
     struct CDFstruct *CDF; struct CCRstruct CCR; struct CPRstruct CPR;
-    int i; long cTotal, uTotal;
+    int i; Int32 cTotal, uTotal;
     SelectCDF (Cur->cdf, CDF)
     /**************************************************************************
     * If multi-file or uncompressed...
@@ -308,7 +314,7 @@ switch (Va->item) {
     else {
       cTotal = MAGIC_NUMBERS_SIZE + CCR.RecordSize + CPR.RecordSize;
       uTotal = MAGIC_NUMBERS_SIZE + CCR.uSize;
-      *cPct = (100L * cTotal) / uTotal;
+      *cPct = (long) (((100.0 * cTotal) / uTotal) + 0.5);
     }
     break;
   }
@@ -718,8 +724,8 @@ switch (Va->item) {
   case rVAR_MAXallocREC_:
   case zVAR_MAXallocREC_: {
     Logical zOp = (Va->item == zVAR_MAXallocREC_), zVar;
-    struct CDFstruct *CDF;
-    Int32 offset, maxRec, lastAllocatedRecN;
+    struct CDFstruct *CDF; struct VarStruct *Var;
+    Int32 offset, maxRec, lastAllocatedRecN; int vType;
     long *maxAllocated = va_arg (Va->ap, long *);
     SelectCDF (Cur->cdf, CDF)
     if (BADzOP(CDF,!zOp)) return ILLEGAL_IN_zMODE;
@@ -728,6 +734,25 @@ switch (Va->item) {
     zVar = CurrentVarMode(CDF,zOp);
     if (zModeON(CDF) || zVar) offset = CDF->CURzVarOffset;
     else offset = CDF->CURrVarOffset;
+    if (zModeON(CDF))
+      if (CDF->CURzVarNum < CDF->NrVars)
+        Var = CDF->rVars[(int)CDF->CURzVarNum];
+      else
+        Var = CDF->zVars[(int)(CDF->CURzVarNum - CDF->NrVars)];
+    else
+      Var = BOO(zOp,CDF->zVars[(int)CDF->CURzVarNum],
+                    CDF->rVars[(int)CDF->CURrVarNum]);
+
+    if (!sX(ReadVDR(CDF,CDF->fp,offset,zVar,
+                    VDR_MAXREC,&maxRec,
+                    VDR_NULL),&pStatus)) {
+      AbortAccess (CDF, UPDATE, noDELETE);
+      return pStatus;
+    }
+    if (!sX(VariableType(CDF,offset,zVar,&vType),&pStatus)) {
+      AbortAccess (CDF, UPDATE, noDELETE);
+      return pStatus;
+    }
 
     /**************************************************************************
     * If a single-file CDF, pass back the maximum record number allocated.
@@ -739,17 +764,31 @@ switch (Va->item) {
 	AbortAccess (CDF, UPDATE, noDELETE);
 	return pStatus;
       }
+      if (vType == SPARSE_RECORDS_) {
+          if (Var != NULL) {
+            if (Var->stage.areaOffset64 != (OFF_T) NO_OFFSET64 &&
+                Var->stage.firstRec != NO_RECORD) {
+              Int32 tmp = (Var->stage.lastRec > maxRec ? maxRec :
+                           Var->stage.lastRec);
+              lastAllocatedRecN += (tmp - Var->stage.firstRec + 1);
+            }
+          }
+      } else if (vType == COMPRESSED_ ||
+                 vType == SPARSE_COMPRESSED_RECORDS_) {
+        if (Var != NULL) {
+          if (Var->stage.areaOffset64 != (OFF_T) NO_OFFSET64 &&
+              Var->stage.firstRec != NO_RECORD &&
+              Var->stage.dotOffset64 == (OFF_T) NO_OFFSET64) {
+            Int32 tmp = (Var->stage.lastRec > maxRec ? maxRec :
+                         Var->stage.lastRec);
+            lastAllocatedRecN += (tmp - Var->stage.firstRec + 1);
+          }
+        }
+      }
       *maxAllocated = lastAllocatedRecN;
     }
-    else {
-      if (!sX(ReadVDR(CDF,CDF->fp,offset,zVar,
-		      VDR_MAXREC,&maxRec,
-		      VDR_NULL),&pStatus)) {
-	AbortAccess (CDF, UPDATE, noDELETE);
-	return pStatus;
-      }
+    else
       *maxAllocated = (long) maxRec;
-    }
     break;
   }
   /****************************************************************************
@@ -844,6 +883,7 @@ switch (Va->item) {
   case zVAR_NUMallocRECS_: {
     Logical zOp = (Va->item == zVAR_NUMallocRECS_), zVar;
     struct CDFstruct *CDF; Int32 offset, nAllocated; int vType;
+    Int32 tMaxRec; struct VarStruct *Var;
     long *nAllocatedP = va_arg (Va->ap, long *);
     SelectCDF (Cur->cdf, CDF)
     if (BADzOP(CDF,!zOp)) return ILLEGAL_IN_zMODE;
@@ -852,8 +892,17 @@ switch (Va->item) {
     zVar = CurrentVarMode(CDF,zOp);
     if (zModeON(CDF) || zVar) offset = CDF->CURzVarOffset;
     else offset = CDF->CURrVarOffset;
+    if (zModeON(CDF))
+      if (CDF->CURzVarNum < CDF->NrVars)
+        Var = CDF->rVars[(int)CDF->CURzVarNum];
+      else
+        Var = CDF->zVars[(int)(CDF->CURzVarNum - CDF->NrVars)];
+    else
+      Var = BOO(zOp,CDF->zVars[(int)CDF->CURzVarNum],
+                    CDF->rVars[(int)CDF->CURrVarNum]);
 
     if (!sX(ReadVDR(CDF,CDF->fp,offset,zVar,
+		    VDR_MAXREC,&tMaxRec,
 		    VDR_NULL),&pStatus)) {
       AbortAccess (CDF, UPDATE, noDELETE);
       return pStatus;
@@ -871,13 +920,35 @@ switch (Va->item) {
       case COMPRESSED_:
       case SPARSE_COMPRESSED_RECORDS_:
       case SPARSE_ARRAYS_:
-      case SPARSE_RECORDS_AND_ARRAYS_:
+      case SPARSE_RECORDS_AND_ARRAYS_: {
 
 	if (!sX(IndexingStatistics(CDF,offset,
 				   zVar,NULL,NULL,
 				   &nAllocated,
 				   NULL,NULL),&pStatus)) return pStatus;
+        if (vType == SPARSE_RECORDS_) {
+          if (Var != NULL) {
+            if (Var->stage.areaOffset != NO_OFFSET &&
+                Var->stage.firstRec != NO_RECORD) {
+              Int32 tmp = (Var->stage.lastRec > tMaxRec ? tMaxRec :
+                           Var->stage.lastRec);
+              nAllocated += (tmp - Var->stage.firstRec + 1);
+            }
+          }
+        } else if (vType == COMPRESSED_ ||
+                   vType == SPARSE_COMPRESSED_RECORDS_) {
+          if (Var != NULL) {
+            if (Var->stage.areaOffset != NO_OFFSET &&
+                Var->stage.firstRec != NO_RECORD &&
+                Var->stage.dotOffset == NO_OFFSET) {
+              Int32 tmp = (Var->stage.lastRec > tMaxRec ? tMaxRec :
+                           Var->stage.lastRec);
+              nAllocated += (tmp - Var->stage.firstRec + 1);
+            }
+          }
+        }
 	break;
+      }
       case IN_MULTI_: {
 	Int32 maxRec;
 	if (!sX(ReadVDR(CDF,CDF->fp,offset,zVar,
@@ -1290,7 +1361,7 @@ switch (Va->item) {
       }
     }
     else {
-      DefaultPadValue (dataType, numElems, padValue);
+      DefaultPadValuePre350 (dataType, numElems, padValue);
       if (!sX(ConvertBuffer(HostEncoding(),CDF->decoding,
     		            CDF->negToPosFp0,dataType,
 			    numElems,padValue,padValue),&pStatus)) {
@@ -1424,7 +1495,7 @@ switch (Va->item) {
   case zVARs_RECDATA_: {
     Logical zOp = (Va->item == zVARs_RECDATA_), zVar;
     struct VarStruct *Var; struct CDFstruct *CDF;
-    Int32 recNum, varNt; Byte *tBuffer; int varX;
+    Int32 recNum, varNt; Byte1 *tBuffer; int varX;
     long nVars = va_arg (Va->ap, long);
     long *varNs = va_arg (Va->ap, long *);
     void *buffer = va_arg (Va->ap, char *);
