@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                                    CDF `put' operations, part 1.
 *
@@ -122,7 +127,8 @@ switch (Va->item) {
       Var = BOO(zOp,CDF->zVars[(int)CDF->CURzVarNum],
                     CDF->rVars[(int)CDF->CURrVarNum]);
 
-    if (!ValidDataType(newDataType)) return BAD_DATA_TYPE;
+    if (!ValidDataType(newDataType) || InValidDataType(newDataType))
+      return BAD_DATA_TYPE;
     if (newNumElems != -99 && newNumElems < 1) return BAD_NUM_ELEMS;
     if (!STRINGdataType(newDataType)) {
       if (newNumElems != -99 && newNumElems != 1) return BAD_NUM_ELEMS;
@@ -168,7 +174,7 @@ switch (Va->item) {
     **************************************************************************/
     if (Var != NULL) {
       Var->NvalueElems = newNumElems;
-      Var->NelemBytes = CDFelemSize ((long)newDataType);
+      Var->NelemBytes = (Int32) CDFelemSize ((long)newDataType);
       Var->NvalueBytes = Var->NvalueElems * Var->NelemBytes;
       Var->NphyRecElems = Var->NphyRecValues * Var->NvalueElems;
       Var->NvirtRecElems = Var->NvirtRecValues * Var->NvalueElems;
@@ -869,7 +875,7 @@ switch (Va->item) {
     **************************************************************************/
     Logical zOp = (Va->item == zVARs_RECDATA_), zVar;
     struct VarStruct *Var; struct CDFstruct *CDF;
-    Int32 recNum, varNt; Byte *tBuffer; int varX;
+    Int32 recNum, varNt; Byte1 *tBuffer; int varX;
 #if LIMITof64K
     long nBytes;
 #endif
