@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                                    CDF `put' operations, part 2.
 *
@@ -22,6 +27,8 @@
 *   V2.2  16-Nov-05, M Liu      Changed code for data spec modification. -99
 *                               is passed as a special indicator for the 
 *                               number of elements as it can't be changed.
+*   V2.3  17-Oct-12, M Liu      Not allowed to set SPARSEREC if a variable
+*                               is non-record varying.
 *
 ******************************************************************************/
 
@@ -275,9 +282,6 @@ switch (Va->item) {
       case HUFF_COMPRESSION:
       case AHUFF_COMPRESSION:
       case GZIP_COMPRESSION: {
-/*
-      case ZLIB_COMPRESSION: {
-*/
 	char pathName[DU_MAX_PATH_LEN+1]; struct CPRstruct64 CPR; Int32 pCount;
 	/**********************************************************************
 	* Get read/write access.
@@ -454,9 +458,6 @@ switch (Va->item) {
       case HUFF_COMPRESSION:
       case AHUFF_COMPRESSION:
       case GZIP_COMPRESSION:
-/*
-      case ZLIB_COMPRESSION:
-*/
 	pCount = CompressionParmsCount ((Int32) cType);
 	SetBit32 (&VDR.Flags, VDR_COMPRESSION_BIT);
 	CPR.RecordSize = CPR_BASE_SIZE64 + (pCount * sizeof(Int32));
@@ -533,7 +534,7 @@ switch (Va->item) {
     /**************************************************************************
     * Only apply to Version 2.6 and later CDFs.
     **************************************************************************/
-    if ((version*10+release) < 26) return pStatus;
+    if ((version*100+release) < 206) return CHECKSUM_NOT_ALLOWED;
 
     /**************************************************************************
     * Get write access.
@@ -568,7 +569,7 @@ switch (Va->item) {
   case rVAR_SPARSERECORDS_:
   case zVAR_SPARSERECORDS_: {
     Logical zOp = (Va->item == zVAR_SPARSERECORDS_), zVar;
-    Int32 maxAllocated, maxRec; OFF_T VDRoffset;
+    Int32 maxAllocated, maxRec, flags; OFF_T VDRoffset;
     struct CDFstruct *CDF; struct VarStruct *Var;
     Int32 sRecordsType = (Int32) va_arg (Va->ap, long);
     /**************************************************************************
@@ -613,6 +614,7 @@ switch (Va->item) {
     **************************************************************************/
     if (!sX(ReadVDR64(CDF,CDF->fp,VDRoffset,zVar,
 		      VDR_MAXREC,&maxRec,
+		      VDR_FLAGS,&flags,
 		      VDR_NULL),&pStatus)) {
       AbortAccess64 (CDF, UPDATE, noDELETE);
       return pStatus;
@@ -623,6 +625,8 @@ switch (Va->item) {
       return pStatus;
     }
     if (maxAllocated > NO_RECORD) return CANNOT_SPARSERECORDS;
+    if (!RECvaryBITset(flags) && sRecordsType != NO_SPARSERECORDS)
+      return CANNOT_SPARSERECORDS;
     /**************************************************************************
     * Based on type of sparseness...
     **************************************************************************/
