@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                           Read from internal records for V3 CDF.
 *
@@ -298,7 +303,7 @@ va_dcl
   ***************************************************************************/
   if (read_only_mode == READONLYon && fp->GDR64 == NULL)
   {
-      fp->GDR64 = cdf_AllocateMemory(sizeof(struct GDRstruct64), NULL);
+      fp->GDR64 = cdf_AllocateMemory((size_t)sizeof(struct GDRstruct64), NULL);
       if (fp->GDR64 == NULL) return CRE;
       if (!SEEKv64(fp,offset,vSEEK_SET)) return CRE;
       if (!Read64_64(fp,&(fp->GDR64->RecordSize))) return CRE;
@@ -1765,12 +1770,12 @@ STATICforIDL CDFstatus ReadADRList64 (vFILE *fp)
   * Allocate memory for the list of ADRs 
   ***************************************************************************/
   if (fp->GDR64->NumAttr > 0)
-  fp->ADRList64 = cdf_AllocateMemory(fp->GDR64->NumAttr * 
+  fp->ADRList64 = cdf_AllocateMemory((size_t)fp->GDR64->NumAttr * 
                                      sizeof(struct ADRstruct64**), NULL);
   if (fp->GDR64->NumAttr > 0 && fp->ADRList64 == NULL) return BAD_MALLOC;
   for (i = 0; i < fp->GDR64->NumAttr; i++)
   {
-      fp->ADRList64[i] = cdf_AllocateMemory(sizeof(struct ADRstruct64), NULL);
+      fp->ADRList64[i] = cdf_AllocateMemory((size_t)sizeof(struct ADRstruct64), NULL);
       if (fp->ADRList64[i] == NULL) return BAD_MALLOC;
   };
   /***************************************************************************
@@ -1841,7 +1846,7 @@ STATICforIDL CDFstatus ReadAEDRList64 (vFILE *fp,
   * Allocate memory for the list and initialize each entry to NULL.
   **************************************************************************/
   if (MaxEntry >= 0) {
-      *AEDRList = cdf_AllocateMemory((MaxEntry + 1) * 
+      *AEDRList = cdf_AllocateMemory((size_t)(MaxEntry + 1) * 
                                      sizeof(struct AEDRstructExt64**), NULL);
       if (*AEDRList == NULL) return BAD_MALLOC;
   }
@@ -1862,7 +1867,7 @@ STATICforIDL CDFstatus ReadAEDRList64 (vFILE *fp,
   ***************************************************************************/
   while (NxtAEDR != 0 && iEntries != NumEntries)            
   {
-      TempAEDR = cdf_AllocateMemory(sizeof(struct AEDRstructExt64), NULL);
+      TempAEDR = cdf_AllocateMemory((size_t)sizeof(struct AEDRstructExt64), NULL);
       if (TempAEDR == NULL) return BAD_MALLOC;
       if (!SEEKv64(fp,NxtAEDR,vSEEK_SET)) return CRE;
       if (!Read64_64(fp,&temp)) return CRE;
@@ -1885,7 +1890,7 @@ STATICforIDL CDFstatus ReadAEDRList64 (vFILE *fp,
       if (TempAEDR->ValueSize < 1) {
         return CV3C;
       }
-      TempAEDR->Value = cdf_AllocateMemory(TempAEDR->ValueSize, NULL);
+      TempAEDR->Value = cdf_AllocateMemory((size_t)TempAEDR->ValueSize, NULL);
       if (TempAEDR->Value == NULL) return BAD_MALLOC;
       if (!READv64(TempAEDR->Value,TempAEDR->ValueSize,1,fp)) return CRE;
       ++iEntries;
