@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                                     CDF `select' operations.
 *
@@ -390,7 +395,7 @@ switch (Va->item) {
     Logical zOp = (Va->item == zVAR_);
     struct CDFstruct *CDF;
     Int32 offset;
-    long varNum = va_arg (Va->ap, long);
+    Int32 varNum = (Int32) va_arg (Va->ap, long);
     SelectCDF (Cur->cdf, CDF)
     if (BADzOP(CDF,!zOp)) return ILLEGAL_IN_zMODE;
     if (varNum < 0) return BAD_VAR_NUM;
@@ -517,7 +522,7 @@ switch (Va->item) {
   case rVARs_RECCOUNT_:
   case rVARs_RECINTERVAL_: {
     struct CDFstruct *CDF;
-    long value = va_arg (Va->ap, long);
+    Int32 value = (Int32) va_arg (Va->ap, long);
     SelectCDF (Cur->cdf, CDF)
     if (BADzOP(CDF,TRUE)) return ILLEGAL_IN_zMODE;
     if (CDF->NrVars == 0) {
@@ -547,7 +552,7 @@ switch (Va->item) {
   case zVAR_RECINTERVAL_: {
     struct CDFstruct *CDF;
     struct VarStruct *Var;
-    long value = va_arg (Va->ap, long);
+    Int32 value = (Int32) va_arg (Va->ap, long);
     SelectCDF (Cur->cdf, CDF)
     if (!CURRENTvarSELECTED(CDF,TRUE)) return NO_VAR_SELECTED;
     if (!sX(InitCurrentVar(CDF,TRUE,&Var),&pStatus)) {
@@ -576,7 +581,7 @@ switch (Va->item) {
   case zVARs_RECNUMBER_: {
     struct CDFstruct *CDF;
     struct VarStruct *Var;
-    long recNumber = va_arg (Va->ap, long); Int32 varN;
+    Int32 recNumber = (Int32) va_arg (Va->ap, long); Int32 varN;
     SelectCDF (Cur->cdf, CDF)
     if (zModeON(CDF)) {
       if (CDF->NrVars + CDF->NzVars == 0) {
@@ -631,7 +636,7 @@ switch (Va->item) {
 	   if (values[dimN] < 0 || CDF->rDimSizes[dimN] <= values[dimN])
 	     return BAD_DIM_INDEX;
 	   else
-	     CDF->rRD.dimIndices[dimN] = values[dimN];
+	     CDF->rRD.dimIndices[dimN] = (Int32) values[dimN];
 	break;
       }
       case rVARs_DIMCOUNTS_:
@@ -639,14 +644,14 @@ switch (Va->item) {
 	   if (values[dimN] < 1)
 	     return BAD_DIM_COUNT;
 	   else
-	     CDF->rRD.dimCounts[dimN] = values[dimN];
+	     CDF->rRD.dimCounts[dimN] = (Int32) values[dimN];
 	break;
       case rVARs_DIMINTERVALS_:
 	for (dimN = 0; dimN < CDF->rNumDims; dimN++)
 	   if (values[dimN] < 1)
 	     return BAD_DIM_INTERVAL;
 	   else
-	     CDF->rRD.dimIntervals[dimN] = values[dimN];
+	     CDF->rRD.dimIntervals[dimN] = (Int32) values[dimN];
 	break;
     }
     break;
@@ -673,21 +678,21 @@ switch (Va->item) {
 	   if (values[dimN] < 0 || Var->dimSizes[dimN] <= values[dimN])
 	     return BAD_DIM_INDEX;
 	   else
-	     Var->zRD.dimIndices[dimN] = values[dimN];
+	     Var->zRD.dimIndices[dimN] = (Int32) values[dimN];
 	break;
       case zVAR_DIMCOUNTS_:
 	for (dimN = 0; dimN < Var->numDims; dimN++)
 	   if (values[dimN] < 1)
 	     return BAD_DIM_COUNT;
 	   else
-	     Var->zRD.dimCounts[dimN] = values[dimN];
+	     Var->zRD.dimCounts[dimN] = (Int32) values[dimN];
 	break;
       case zVAR_DIMINTERVALS_:
 	for (dimN = 0; dimN < Var->numDims; dimN++)
 	   if (values[dimN] < 1)
 	     return BAD_DIM_INTERVAL;
 	   else
-	     Var->zRD.dimIntervals[dimN] = values[dimN];
+	     Var->zRD.dimIntervals[dimN] = (Int32) values[dimN];
 	break;
     }
     break;
