@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF				      CDF character string handling.
 *
@@ -45,8 +50,8 @@
 struct DESCRstruct {
   void *ptr;
   short length;
-  Byte filler;
-  Byte type;
+  Byte1 filler;
+  Byte1 type;
 };
 #endif
 #endif
@@ -67,7 +72,7 @@ struct STRINGstruct **ssh;		/* Pointer to head of STRINGstruct
   struct STRINGstruct *ss;
 
   if (*ssh == NULL) {	/* First string. */
-    *ssh = (struct STRINGstruct *) cdf_AllocateMemory (sizeof(struct STRINGstruct),
+    *ssh = (struct STRINGstruct *) cdf_AllocateMemory ((size_t)sizeof(struct STRINGstruct),
 						   NULL);
     if (*ssh == NULL) return NULL;
     ss = *ssh;
@@ -76,14 +81,14 @@ struct STRINGstruct **ssh;		/* Pointer to head of STRINGstruct
     ss = *ssh;
     while (ss->next != NULL) ss = ss->next;
     ss->next = (struct STRINGstruct *)
-	       cdf_AllocateMemory (sizeof(struct STRINGstruct), NULL);
+	       cdf_AllocateMemory ((size_t)sizeof(struct STRINGstruct), NULL);
     if (ss->next == NULL) return NULL;
     ss = ss->next;
   }
 
   ss->next = NULL;
 
-  ss->string = (char *) cdf_AllocateMemory (length + 1, NULL);
+  ss->string = (char *) cdf_AllocateMemory ((size_t)length + 1, NULL);
   if (ss->string == NULL) return NULL;
 
   memmove (ss->string, string, length);
