@@ -1,3 +1,8 @@
+/******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
 /****************************************************************************** 
 *
 *  SPDF/CDF                       CDF_TIME_TT2000 utility routines for C.
@@ -247,18 +252,18 @@ static void LoadLeapSecondsTable ()
           ++count;
         }
         rewind(leaptable);
-        LTD = (double **) malloc (count * sizeof (double *));
+        LTD = (double **) cdf_AllocateMemory (count * sizeof (double *), NULL);
         ix = 0;
         while (fgets(line, 80, leaptable)) {
           if (line[0] == ';') continue;
-          LTD[ix] = (double *) malloc(6 * sizeof(double));
+          LTD[ix] = (double *) cdf_AllocateMemory(6 * sizeof(double), NULL);
           im = sscanf (line, "%ld %ld %ld %lf %lf %lf", &yy, &mm, &dd,
                        &(LTD[ix][3]), &(LTD[ix][4]), &(LTD[ix][5]));
           if (im != 6) {
             int iz;
             for (iz = 0; iz < ix; ++iz)
-              free (LTD[iz]);
-            free (LTD);
+              cdf_FreeMemory (LTD[iz], NULL);
+            cdf_FreeMemory (LTD, NULL);
             togo = 0;
             break;
           }
@@ -275,9 +280,9 @@ static void LoadLeapSecondsTable ()
       }
     }
     if (fromFile == 0) {
-      LTD = (double **) malloc (NDAT * sizeof (double *));
+      LTD = (double **) cdf_AllocateMemory (NDAT * sizeof (double *), NULL);
       for (ix = 0; ix < NDAT; ++ix) {
-        LTD[ix] = (double *) malloc(6 * sizeof(double));
+        LTD[ix] = (double *) cdf_AllocateMemory(6 * sizeof(double), NULL);
         LTD[ix][0] = LTS[ix][0];
         LTD[ix][1] = LTS[ix][1];
         LTD[ix][2] = LTS[ix][2];
@@ -294,7 +299,7 @@ static void LoadLeapNanoSecondsTable ()
 {
   int ix;
   if (LTD == NULL) LoadLeapSecondsTable ();
-  NST = (long long *) malloc (entryCnt * sizeof (long long));
+  NST = (long long *) cdf_AllocateMemory (entryCnt * sizeof (long long), NULL);
   for (ix = NERA1; ix < entryCnt; ++ix)
      NST[ix] = CDF_TT2000_from_UTC_parts(LTD[ix][0], LTD[ix][1],
                                          LTD[ix][2], 0.0, 0.0, 0.0,
@@ -375,9 +380,9 @@ VISIBLE_PREFIX void CDFClearLeapSecondsTable ()
   int ix;
   if (LTD != NULL) {
     for (ix = 0; ix < entryCnt; ++ix)
-       free (LTD[ix]);
-    free (LTD);
-    free (NST);
+       cdf_FreeMemory (LTD[ix], NULL);
+    cdf_FreeMemory (LTD, NULL);
+    if (NST != NULL) cdf_FreeMemory (NST, NULL);
     LTD = NULL;
     NST = NULL;
   }
@@ -467,7 +472,7 @@ va_dcl
 #if defined(STDARG)
   va_start (Va, ld);
 #else
-  va_start (Va);
+  VA_START (Va);
 #endif
   ix = 0;
   tmp = va_arg (Va, double *);
@@ -517,6 +522,7 @@ va_dcl
   toPlus = 0;
   t3 = nanoSecSinceJ2000;
   dat0 = LeapSecondsfromJ2000 (nanoSecSinceJ2000, &leapSec);
+/*
   nanoSecSinceJ2000 -= dTinNanoSecs;
   nanoSecSinceJ2000 += T12hinNanoSecs;
   t2 = nanoSecSinceJ2000;
@@ -526,6 +532,17 @@ va_dcl
     nansec = SECinNanoSecs + nansec;
     --secSinceJ2000;
   }
+*/
+  secSinceJ2000 = (long) ((double)nanoSecSinceJ2000/SECinNanoSecsD);
+  nansec = (long) (nanoSecSinceJ2000 - secSinceJ2000 * SECinNanoSecs);
+  secSinceJ2000 += 43200; /* secs in T12hinNanoSecs */
+  secSinceJ2000 -= 32; /* secs in dTinNanoSecs */
+  nansec -= 184000000L; /* nanosec in dTinNanoSecs */
+  if (nansec < 0) {
+    nansec = SECinNanoSecs + nansec;
+    --secSinceJ2000;
+  }
+  t2 = secSinceJ2000 * SECinNanoSecs + nansec;
   if (dat0 > 0.0) { /* Post-1972.... */
     secSinceJ2000 -= (long long) dat0;
     epoch = (double) J2000Since0AD12hSec + secSinceJ2000;
@@ -660,7 +677,7 @@ va_dcl
 #if defined(STDARG)
   va_start (Va, dd);
 #else
-  va_start (Va);
+  VA_START (Va);
 #endif
   ix = 0;
   tmp = va_arg (Va, double);
@@ -894,12 +911,7 @@ va_dcl
   else if (lyl == 0 && lml == 1 && ldl == 1 && lhl == 0 && lnl == 0 &&
            lsl == 0 && lll == 0 && lul == 0 && lal == 0)
     return DEFAULT_TT2000_PADVALUE;
-/*
-  else if (lyl == 1710 && lml == 1 && ldl == 1 && lhl == 0 && lnl == 0 &&
-           lsl == 0 && lll == 0 && lul == 0 && lal == 0)
-    return ILLEGAL_TT2000_VALUE;
-*/
-  if ((yy-lyl) != 0.0 || (mm-lml) != 0.0) return ILLEGAL_TT2000_VALUE;
+/*  if ((yy-lyl) != 0.0 || (mm-lml) != 0.0) return ILLEGAL_TT2000_VALUE; */
   if (!YearWithin(lyl) && !ValidateYMD(lyl,lml,ldl))
     return ILLEGAL_TT2000_VALUE;
   iy = 10000000 * lml + 10000 * ldl + lyl;
@@ -951,7 +963,7 @@ VISIBLE_PREFIX long long CDF_TT2000_from_UTC_EPOCH (double epoch)
   if (epoch == -1.0E31 || epoch == -1.0E-31)
     return FILLED_TT2000_VALUE; 
   if (epoch == 0.0 || NegativeZeroReal8 (&epoch))
-    return DEFAULT_TT2000_PADVALUE;; 
+    return DEFAULT_TT2000_PADVALUE;
   EPOCHbreakdown (epoch, &yy, &mm, &dd, &hh, &nn, &ss, &ll);
   if (!YearWithin(yy) && !ValidateYMD(yy,mm,dd)) return ILLEGAL_TT2000_VALUE;
   return CDF_TT2000_from_UTC_parts ((double)yy, (double)mm, (double)dd,
@@ -1026,7 +1038,7 @@ va_dcl
 #if defined(STDARG)
   va_start (Va, string);
 #else
-  va_start (Va);
+  VA_START (Va);
 #endif
   format = va_arg (Va, int);
   if (format < 0 || format > 3) format = 3;
