@@ -1,3 +1,8 @@
+/******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
 /*****************************************************************************e
 *
 *  NSSDC/CDF                            Quick Start Test Program (C interface).
@@ -67,8 +72,8 @@ int main () {
 CDFid           id;
 CDFstatus       status;
 int             dim_n;
-static long     encoding = NETWORK_ENCODING;
-static long     actual_encoding = NETWORK_ENCODING;
+static long     encoding = IBMPC_ENCODING;
+static long     actual_encoding = IBMPC_ENCODING;
 static long     majority = ROW_MAJOR;
 static long     checkSum = MD5_CHECKSUM, checkSum_out;
 static long     numDims = N_DIMS;
