@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                  Quick Start Test Program (STANDARD interface/C).
 *
@@ -74,8 +79,8 @@ int main () {
 /* CDFid id; */
 CDFstatus status;
 int dim_n;
-static long encoding = NETWORK_ENCODING;
-static long actual_encoding = NETWORK_ENCODING;
+static long encoding = IBMPC_ENCODING;
+static long actual_encoding = IBMPC_ENCODING;
 static long majority = ROW_MAJOR;
 static long numDims = N_DIMS;
 static long dimSizes[N_DIMS] = { DIM_0_SIZE, DIM_1_SIZE };
@@ -390,7 +395,7 @@ if (status < CDF_OK) QuitCDF ("6.0", status);
 status = CDFcreateCDF("TEST", &id);
 if (status < CDF_OK) QuitCDF ("7.0", status);
 
-status = CDFsetEncoding (id, NETWORK_ENCODING);
+status = CDFsetEncoding (id, IBMPC_ENCODING);
 if (status < CDF_OK) QuitCDF ("7.1", status);
 
 status = CDFsetMajority (id, ROW_MAJOR);
@@ -983,7 +988,7 @@ if (maxZentry != 0) QuitCDF ("31.21", status);
 if (numZentries != 1) QuitCDF ("31.22", status);
 if (maxRecOut != 2L) QuitCDF ("31.23", status);
 if (numDimsX != numDimsY || numDimsX != 0) QuitCDF ("31.24", status);
-if (encodingX != encodingY || encodingX != NETWORK_ENCODING) QuitCDF ("31.25", status);
+if (encodingX != encodingY || encodingX != IBMPC_ENCODING) QuitCDF ("31.25", status);
 if (majorityX != majorityY || majorityX != ROW_MAJOR) QuitCDF ("31.26", status);
 /* if (maxrRecX != maxrRecY || maxrRecX != 0) QuitCDF ("31.27", status); */
 if (nrVarsX != nrVarsY || nrVarsX != 0) QuitCDF ("31.28", status);
