@@ -1,4 +1,9 @@
 	PROGRAM QST2F
+C-----------------------------------------------------------------------
+C Copyright 1996-2013 United States Government as represented by the
+C Administrator of the National Aeronautics and Space Administration.
+C All Rights Reserved.
+C-----------------------------------------------------------------------
 
 C-----------------------------------------------------------------------
 C
@@ -111,13 +116,15 @@ C					! (before padding blanks begin)
 	CHARACTER EPSTRING*(EPOCH_STRING_LEN),
      .		  EPSTRING1*(EPOCH1_STRING_LEN),
      .		  EPSTRING2*(EPOCH2_STRING_LEN),
-     .		  EPSTRING3*(EPOCH3_STRING_LEN)
+     .		  EPSTRING3*(EPOCH3_STRING_LEN),
+     .		  EPSTRING4*(EPOCH4_STRING_LEN)
 	CHARACTER EPSTRING_TRUE*(EPOCH_STRING_LEN),
      .		  EPSTRING1_TRUE*(EPOCH1_STRING_LEN),
      .		  EPSTRING2_TRUE*(EPOCH2_STRING_LEN),
-     .		  EPSTRING3_TRUE*(EPOCH3_STRING_LEN)
+     .		  EPSTRING3_TRUE*(EPOCH3_STRING_LEN),
+     .		  EPSTRING4_TRUE*(EPOCH4_STRING_LEN)
 
-	DATA ENCODING/NETWORK_ENCODING/
+	DATA ENCODING/IBMPC_ENCODING/
 	DATA MAJORITY/COL_MAJOR/
         DATA CHECKSUM/MD5_CHECKSUM/
 	DATA NUM_DIMS/N_DIMS/
@@ -150,7 +157,8 @@ C					! (before padding blanks begin)
 	DATA EPSTRING_TRUE/'13-Oct-1994 12:00:00.000'/,
      .	     EPSTRING1_TRUE/'19941013.5000000'/,
      .	     EPSTRING2_TRUE/'19941013120000'/,
-     .	     EPSTRING3_TRUE/'1994-10-13T12:00:00.000Z'/
+     .	     EPSTRING3_TRUE/'1994-10-13T12:00:00.000Z'/,
+     .	     EPSTRING4_TRUE/'1994-10-13T12:00:00.000'/
 
 C-----------------------------------------------------------------------
 C  NUL-terminate character strings.
@@ -260,8 +268,8 @@ C-----------------------------------------------------------------------
      .	    CALL QUIT_CDF (STATUS, '6a.2')
 	END DO
 
-	IF (ENCODING_OUT .NE. ENCODING)
-     .	  CALL QUIT_CDF (STATUS, '6a.3')
+C	IF (ENCODING_OUT .NE. ENCODING)
+C    .	  CALL QUIT_CDF (STATUS, '6a.3')
 	IF (MAJORITY_OUT .NE. MAJORITY)
      .	  CALL QUIT_CDF (STATUS, '6a.4')
 	IF (MAX_REC_OUT .NE. 0) CALL QUIT_CDF (STATUS, '6a.5')
@@ -424,8 +432,8 @@ C-----------------------------------------------------------------------
      .	    CALL QUIT_CDF (STATUS, '16.2')
 	END DO
 
-	IF (ENCODING_OUT .NE. ENCODING)
-     .	  CALL QUIT_CDF (STATUS, '16.3')
+C	IF (ENCODING_OUT .NE. ENCODING)
+C    .	  CALL QUIT_CDF (STATUS, '16.3')
 	IF (MAJORITY_OUT .NE. MAJORITY)
      .	  CALL QUIT_CDF (STATUS, '16.4')
 	IF (MAX_REC_OUT .NE. 1) CALL QUIT_CDF (STATUS, '16.5')
@@ -564,6 +572,12 @@ C-----------------------------------------------------------------------
 	CALL PARSE_EPOCH3 (EPSTRING3, EPOCH_OUT)
 	IF (EPOCH_OUT .NE. EPOCH) CALL QUIT_EPOCH ('30.7')
 
+	CALL ENCODE_EPOCH4 (EPOCH, EPSTRING4)
+	IF (EPSTRING4 .NE. EPSTRING4_TRUE) CALL QUIT_EPOCH ('30.8')
+
+	CALL PARSE_EPOCH4 (EPSTRING4, EPOCH_OUT)
+	IF (EPOCH_OUT .NE. EPOCH) CALL QUIT_EPOCH ('30.9')
+
 	CALL EPOCH_BREAKDOWN (EPOCH, YEAR_OUT, MONTH_OUT, DAY_OUT,
      .			      HOUR_OUT, MINUTE_OUT, SECOND_OUT,
      .			      MSEC_OUT)
@@ -584,13 +598,17 @@ C  QUIT_CDF.  Abort test early due to CDF error.
 C-----------------------------------------------------------------------
 
 	SUBROUTINE QUIT_CDF (STATUS, WHERE)
+	INCLUDE 'CDF.INC'
 	INTEGER*4 STATUS
 	CHARACTER WHERE*(*)
+	CHARACTER TEXT*(CDF_ERRTEXT_LEN)
+	INTEGER*4 STATUS2
 	WRITE (6,401) WHERE
  401	FORMAT (' ', 'Aborting at ', A, '...')
 	IF (STATUS .LT. 0) THEN
+	  CALL CDF_ERROR (STATUS, TEXT, STATUS2)
 	  WRITE (6,501) STATUS
- 501	  FORMAT (' ', 'CDF status code: ', I5)
+ 501	  FORMAT (' ', 'ERROR: ', A)
 	ENDIF
 	WRITE (6,404)
  404	FORMAT (' ','...test aborted')
