@@ -1,5 +1,9 @@
 	PROGRAM QST2IF
-
+C-----------------------------------------------------------------------
+C Copyright 1996-2013 United States Government as represented by the
+C Administrator of the National Aeronautics and Space Administration.
+C All Rights Reserved.
+C-----------------------------------------------------------------------
 C-----------------------------------------------------------------------
 C
 C  NSSDC/CDF	  Quick Start Test Program (INTERNAL interface/FORTRAN).
@@ -31,6 +35,7 @@ C
 C-----------------------------------------------------------------------
 
         INCLUDE 'CDF.INC'
+        INTEGER (KIND=KIND_INT8) uSizeOUT8, cSizeOUT8
 		
 	INTEGER*4 ID, STATUS, ENCODING, MAJORITY, NUM_DIMS,
      .            CHECKSUM, CHECKSUM_out,
@@ -48,12 +53,12 @@ C-----------------------------------------------------------------------
      .		  INCREMENTlib, RELEASEcdf, VERSIONcdf, INCREMENTcdf,
      .		  I, X1, X2, X, decodingOut,
      .		  VAR_REC_VARIANCE, VAR_REC_VARIANCE_OUT, recnum_out,
-     .		  VAR_DIM_VARIANCES(2), reccount_out, cSizeOUT,
+     .		  VAR_DIM_VARIANCES(2), reccount_out, cSizeOUT4,
      .		  VAR_DIM_VARIANCES_OUT(2),  recinterval_out,
      .		  dimindices_out(CDF_MAX_DIMS), datatype_size,
      .		  dimcounts_out(CDF_MAX_DIMS), cType, cTypeOUT,
      .		  dimintervals_out(CDF_MAX_DIMS), cParms(CDF_MAX_PARMS)
-        INTEGER*4 cParmsOUT(CDF_MAX_PARMS), cPctOUT, uSizeOUT,
+        INTEGER*4 cParmsOUT(CDF_MAX_PARMS), cPctOUT, uSizeOUT4,
      .		  sRecordsType, sArraysType, sRecordsTypeOUT,
      .		  sArraysParms(CDF_MAX_PARMS), sArraysTypeOUT,
      .		  sArraysParmsOUT(CDF_MAX_PARMS), sArraysPctOUT,
@@ -75,7 +80,7 @@ C-----------------------------------------------------------------------
      .		  VAR_BUFFER_OUT(2,3)*5,
      .		  SUBINCREMENTlib*1, nameOut*(CDF_PATHNAME_LEN)
 
-	DATA ENCODING/NETWORK_ENCODING/, MAJORITY/COL_MAJOR/,
+	DATA ENCODING/IBMPC_ENCODING/, MAJORITY/COL_MAJOR/,
      .       CHECKSUM/MD5_CHECKSUM/,
      .	     NUM_DIMS/2/, DIM_SIZES/2,3/,
      .	     VAR_DATA_TYPE/CDF_CHAR/, VAR_NUM_ELEMENTS/5/,
@@ -111,14 +116,17 @@ C-----------------------------------------------------------------------
 	WRITE (6,100)
  100	FORMAT (' ','Testing Internal/FORTRAN interface...')
 
+C	CALL CDF_SET_FILEBACKWARD(BACKWARDFILEon)
+C       CALL CDF_SET_VALIDATE(VALIDATEFILEon)
+
 C-----------------------------------------------------------------------
 C Create CDF.
 C-----------------------------------------------------------------------
-C	CALL CDF_SET_FILEBACKWARD(BACKWARDFILEon)
+
         STATUS = CDF_LIB    (CREATE_, CDF_, CDFNAME, NUM_DIMS,
      .				            DIM_SIZES, ID,
-     .		             PUT_, CDF_ENCODING_, ENCODING,
-     .			           CDF_MAJORITY_, MAJORITY,
+C    .		             PUT_, CDF_ENCODING_, ENCODING,
+     .			     PUT_, CDF_MAJORITY_, MAJORITY,
      .		             NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) THEN
 	  IF (STATUS .EQ. CDF_EXISTS) THEN
@@ -132,8 +140,8 @@ C	CALL CDF_SET_FILEBACKWARD(BACKWARDFILEon)
 
             STATUS = CDF_LIB    (CREATE_, CDF_, CDFNAME, NUM_DIMS,
      .					        DIM_SIZES, ID,
-     .			         PUT_, CDF_ENCODING_, ENCODING,
-     .				       CDF_MAJORITY_, MAJORITY,
+C    .			         PUT_, CDF_ENCODING_, ENCODING,
+     .				 PUT_, CDF_MAJORITY_, MAJORITY,
      .			         NULL_, STATUS)
 	    IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '1.2')
 	   ELSE
@@ -183,8 +191,8 @@ C-----------------------------------------------------------------------
 
         STATUS = CDF_LIB    (CREATE_, CDF_, CDFNAME, NUM_DIMS,
      .				            DIM_SIZES, ID,
-     .		             PUT_, CDF_ENCODING_, ENCODING,
-     .			           CDF_MAJORITY_, MAJORITY,
+C    .		             PUT_, CDF_ENCODING_, ENCODING,
+     .			     PUT_, CDF_MAJORITY_, MAJORITY,
      .			           CDF_COMPRESSION_, cType, cParms,
      .		             NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '6.0')
@@ -219,8 +227,8 @@ C-----------------------------------------------------------------------
      .	    CALL QUIT_CDF (STATUS, '6a.2')
 	END DO
 
-	IF (ENCODING_OUT .NE. ENCODING)
-     .	  CALL QUIT_CDF (STATUS, '6a.3')
+C	IF (ENCODING_OUT .NE. ENCODING)
+C    .	  CALL QUIT_CDF (STATUS, '6a.3')
 	IF (MAJORITY_OUT .NE. MAJORITY)
      .	  CALL QUIT_CDF (STATUS, '6a.4')
 	IF (MAX_REC_OUT .NE. 0) CALL QUIT_CDF (STATUS, '6a.5')
@@ -574,12 +582,10 @@ C-----------------------------------------------------------------------
 	  ENDIF
 	END DO
 
-	IF (ENCODING_OUT .NE. ENCODING) THEN
-	  CALL QUIT_CDF (STATUS, '16.3')
-	ENDIF
-	IF (MAJORITY_OUT .NE. MAJORITY) THEN
-	  CALL QUIT_CDF (STATUS, '16.4')
-	ENDIF
+C	IF (ENCODING_OUT .NE. ENCODING)
+C    .	  CALL QUIT_CDF (STATUS, '16.3')
+	IF (MAJORITY_OUT .NE. MAJORITY)
+     .	  CALL QUIT_CDF (STATUS, '16.4')
 	IF (MAX_REC_OUT .NE. 10) CALL QUIT_CDF (STATUS, '16.5')
 	IF (NUM_VARS_OUT .NE. 3) CALL QUIT_CDF (STATUS, '16.6')
 	IF (NUM_ATTRS_OUT .NE. 1) CALL QUIT_CDF (STATUS, '16.7')
@@ -748,13 +754,18 @@ C-----------------------------------------------------------------------
 C-----------------------------------------------------------------------
 C Get CDF information.
 C-----------------------------------------------------------------------
-
-        STATUS = CDF_LIB   (GET_, CDF_INFO_, CDFNAME, cTypeOUT,
-     .					     cParmsOUT, cSizeOUT,
-     .					     uSizeOUT,
-     .		            NULL_, STATUS)
+        if (VERSIONlib .GE. 3) THEN 
+          STATUS = CDF_LIB   (GET_, CDF_INFO_, CDFNAME, cTypeOUT,
+     .	  				       cParmsOUT, cSizeOUT8,
+     .					       uSizeOUT8,
+     .		              NULL_, STATUS)
+        ELSE
+          STATUS = CDF_LIB   (GET_, CDF_INFO_, CDFNAME, cTypeOUT,
+     .	  				       cParmsOUT, cSizeOUT4,
+     .					       uSizeOUT4,
+     .		              NULL_, STATUS)
+        END IF
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '29.0')
-
 	IF (cTypeOUT .NE. cType) CALL QUIT_CDF (STATUS, '29.1')
 
 C-----------------------------------------------------------------------
@@ -766,13 +777,19 @@ C QUIT_CDF.  Abort test early due to CDF error.
 C-----------------------------------------------------------------------
 
 	SUBROUTINE QUIT_CDF (STATUS, WHERE)
+	INCLUDE 'CDF.INC'
 	INTEGER*4 STATUS
 	CHARACTER WHERE*(*)
+	CHARACTER TEXT*(CDF_ERRTEXT_LEN)
+	INTEGER*4 STATUS2
 	WRITE (6,401) WHERE
  401	FORMAT (' ', 'Aborting at ', A, '...')
 	IF (STATUS .LT. 0) THEN
-	  WRITE (6,501) STATUS
- 501	  FORMAT (' ', 'CDF status code: ', I5)
+	  STATUS2 = CDF_LIB (SELECT_, CDF_STATUS_, STATUS,
+     .                       GET_, STATUS_TEXT_, TEXT,
+     .                       NULL_, STATUS2)
+	  WRITE (6,501) TEXT
+ 501	  FORMAT (' ', 'ERROR: ', A)
 	ENDIF
 	WRITE (6,404)
  404	FORMAT (' ','...test aborted')
