@@ -1,4 +1,9 @@
 	PROGRAM QST2IF
+C-----------------------------------------------------------------------
+C Copyright 1996-2013 United States Government as represented by the
+C Administrator of the National Aeronautics and Space Administration.
+C All Rights Reserved.
+C-----------------------------------------------------------------------
 
 C-----------------------------------------------------------------------
 C
@@ -75,7 +80,7 @@ C-----------------------------------------------------------------------
      .		  VAR_BUFFER_OUT(2,3)*5,
      .		  SUBINCREMENTlib*1, nameOut*(CDF_PATHNAME_LEN)
 
-	DATA ENCODING/NETWORK_ENCODING/, MAJORITY/COL_MAJOR/,
+	DATA ENCODING/IBMPC_ENCODING/, MAJORITY/COL_MAJOR/,
      .	     NUM_DIMS/2/, DIM_SIZES/2,3/,
      .	     VAR_DATA_TYPE/CDF_CHAR/, VAR_NUM_ELEMENTS/5/,
      .	     VAR_REC_VARIANCE/VARY/, VAR_DIM_VARIANCES/VARY,VARY/,
@@ -116,8 +121,8 @@ C-----------------------------------------------------------------------
 
         STATUS = CDF_LIB    (CREATE_, CDF_, CDFNAME, NUM_DIMS,
      .				            DIM_SIZES, ID,
-     .		             PUT_, CDF_ENCODING_, ENCODING,
-     .			           CDF_MAJORITY_, MAJORITY,
+C    .		             PUT_, CDF_ENCODING_, ENCODING,
+     .			     PUT_, CDF_MAJORITY_, MAJORITY,
      .			           CDF_FORMAT_, SINGLE_FILE,
      .		             NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) THEN
@@ -132,8 +137,8 @@ C-----------------------------------------------------------------------
 
             STATUS = CDF_LIB    (CREATE_, CDF_, CDFNAME, NUM_DIMS,
      .					        DIM_SIZES, ID,
-     .			         PUT_, CDF_ENCODING_, ENCODING,
-     .				       CDF_MAJORITY_, MAJORITY,
+C    .			         PUT_, CDF_ENCODING_, ENCODING,
+     .				 PUT_, CDF_MAJORITY_, MAJORITY,
      .				       CDF_FORMAT_, MULTI_FILE,
      .			         NULL_, STATUS)
 	    IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '1.2')
@@ -184,8 +189,8 @@ C-----------------------------------------------------------------------
 
         STATUS = CDF_LIB    (CREATE_, CDF_, CDFNAME, NUM_DIMS,
      .				            DIM_SIZES, ID,
-     .		             PUT_, CDF_ENCODING_, ENCODING,
-     .			           CDF_MAJORITY_, MAJORITY,
+C    .		             PUT_, CDF_ENCODING_, ENCODING,
+     .			     PUT_, CDF_MAJORITY_, MAJORITY,
      .			           CDF_FORMAT_, SINGLE_FILE,
      .			           CDF_COMPRESSION_, cType, cParms,
      .			     SELECT_, CDF_CACHESIZE_, cacheSize,
