@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF						      SkeletonTable.
 *
@@ -194,7 +199,7 @@ switch (argC) {
 	      varValues = ALLvalues;
 	    else {
 	      varValues = NAMEDvalues;
- 	      variables = cdf_AllocateMemory (len + 1, FatalError);
+ 	      variables = cdf_AllocateMemory ((size_t)len + 1, FatalError);
  	      strcpyX (variables, qop->qualOpt[VALUESqual], len);
 	    }
 	  }
@@ -431,10 +436,11 @@ long numDims;
 long dimSizes[CDF_MAX_DIMS];
 long numVars, numZvars, maxRec;
 long numVattrs, numGattrs;
-int dimN;
+int  dimN;
 long version, release, increment;
 char sizes[MAX_SIZES_LEN+1], subIncrement;
 char text[MAX_TEXT_LEN+1], tempS[MAX_LINE_LEN+1];
+long compress, compParms[CDF_MAX_DIMS], compPct, checkSum;
 
 status = CDFlib (GET_, CDF_VERSION_, &version,
 		       CDF_RELEASE_, &release,
@@ -526,6 +532,28 @@ if (numDims > 0) {
   WriteOut (SKTfp, sizes);
 }
 
+status = CDFlib (GET_, CDF_COMPRESSION_, &compress, compParms, &compPct,
+                 NULL_);
+if (!StatusHandlerC2S(status)) return FALSE;
+
+/*
+if (compress != NO_COMPRESSION || compress != NO_CHECKSUM)
+  WriteOutFP (SKTfp, "\n");
+*/
+
+/* if (compress != NO_COMPRESSION) */
+  WriteOutFP (SKTfp, "\n! CDF_COMPRESSION: %s",
+              CompressionToken(compress, compParms));
+  WriteOutFP (SKTfp, "\n! (Valid compression: None, GZIP.1-9, RLE.0, HUFF.0, AHUFF.0)");
+
+status = CDFlib (GET_, CDF_CHECKSUM_, &checkSum,
+                 NULL_);
+if (!StatusHandlerC2S(status)) return FALSE;
+
+/* if (checkSum != NO_CHECKSUM) */
+  WriteOutFP (SKTfp, "\n! CDF_CHECKSUM: %s", ChecksumToken(checkSum)); 
+  WriteOutFP (SKTfp, "\n! (Valid checksum: None, MD5)");
+
 return TRUE;
 }
 
@@ -661,6 +689,12 @@ if (numAttrs > 0) {
        * Write '.' after last entry.
        ***********************************************************************/
        WriteOut (SKTfp, " .");
+       if (!ISTPname(attrName)) {
+         WriteOut (SKTfp, "\n");
+         WriteOutFP (SKTfp,
+                     "!  Warning: \"%s\": Not ISTP compliant... not recommended",
+                     attrName);
+       }
      }
      CHECKforABORTso
   }
@@ -710,6 +744,12 @@ if (numAttrs > 0) {
        snprintf (tempS, (size_t) sizeof(tempS),
 		 "\n  %c%s%c", delim, attrName, delim);
        WriteOut (SKTfp, tempS);
+       if (!ISTPname(attrName)) {
+         WriteOut (SKTfp, "\n");
+         WriteOutFP (SKTfp,
+                     "!  Warning: \"%s\": Not ISTP compliant... not recommended",
+                     attrName);
+       }
      }
      CHECKforABORTso
   }
@@ -793,7 +833,12 @@ int VattrCount;
 char varys[MAX_VARYS_LEN+1];
 char sizes[MAX_SIZES_LEN+1];
 char tempS[MAX_LINE_LEN+1];
+long cType, cParms[CDF_MAX_DIMS], cPct, sparse, bf;
+void *pad = NULL;
+int padValue;
+long sarray[CDF_MAX_PARMS];
 
+sarray[0] = 0;
 status = CDFlib (SELECT_, VAR(zVar), varN,
 		 GET_, VAR_NAME(zVar), varName,
 		       VAR_DATATYPE(zVar), &varDataType,
@@ -801,6 +846,9 @@ status = CDFlib (SELECT_, VAR(zVar), varN,
 		       VAR_RECVARY(zVar), &recVary,
 		       VAR_DIMVARYS(zVar), dimVarys,
 		       VAR_MAXREC(zVar), &maxRec,
+		       VAR_COMPRESSION(zVar), &cType, cParms, &cPct,
+		       VAR_SPARSERECORDS(zVar), &sparse,
+		       VAR_BLOCKINGFACTOR(zVar), &bf,
 		 NULL_);
 if (!StatusHandlerC2S(status)) return FALSE;
 
@@ -815,6 +863,18 @@ else
 		   NULL_);
 if (!StatusHandlerC2S(status)) return FALSE;
 
+pad = cdf_AllocateMemory ((size_t) ((varNumElements + 
+                                     (STRINGdataType(varDataType)? 1 : 0)) *
+                                    CDFelemSize(varDataType)),
+                          FatalError);
+status = CDFlib (GET_, VAR_PADVALUE(zVar), pad,
+                 NULL_);
+if (!StatusHandlerC2S(status)) return FALSE;
+if (status != NO_PADVALUE_SPECIFIED)
+  padValue = 1;
+else
+  padValue = 0;
+
 /***************************************************************************
 * If zVariable, build dimension sizes string.
 ***************************************************************************/
@@ -954,6 +1014,69 @@ if (numDims > 0) {
   WriteOut (SKTfp, varys);
 }
 
+WriteOutFP (SKTfp, "\n");
+
+if (!ISTPname(varName)) {
+  WriteOutFP (SKTfp, "!  Warning: \"%s\": Not ISTP compliant... not recommended",
+              varName);
+}
+
+/* if (cType != NO_COMPRESSION) */
+  WriteOutFP (SKTfp, "\n  ! VAR_COMPRESSION: %s",
+              CompressionToken(cType, cParms));
+  WriteOutFP (SKTfp, "\n  ! (Valid compression: None, GZIP.1-9, RLE.0, HUFF.0, AHUFF.0)");
+
+/* if (recVary == VARY) { */
+  WriteOutFP (SKTfp, "\n  ! VAR_SPARSERECORDS: %s",
+            SparsenessToken(sparse, NO_SPARSEARRAYS, sarray));
+  WriteOutFP (SKTfp, "\n  ! (Valid sparserecords: None, sRecords.PAD, sRecords.PREV)");
+/* } */
+
+if (bf != 0) {
+  WriteOutFP (SKTfp, "\n  ! VAR_BLOCKINGFACTOR: %ld", bf);
+}
+
+if (STRINGdataType(varDataType)) {
+  int ix, iy;
+  if (padValue == 0) { /* Only output a single blank */
+    *(((char *) pad)+0) = (char) DEFAULT_CHAR_PADVALUE;
+    *(((char *) pad)+1) = (char) '\0';
+  } else {
+    iy = -1;
+    for (ix = 0; ix < (int) varNumElements; ++ix)
+      if (!Printable(*(((char *) pad)+ix))) *(((char *) pad)+ix) = '.';
+    for (ix = (varNumElements-1); ix >= 0; --ix) {
+      if (*(((char *) pad)+ix) != ' ') {
+        iy = ix;
+        break;
+      }
+    }
+    if (iy == -1) /* All blanks... output a single blank */
+      *(((char *) pad)+1) = (char) '\0';
+    else
+      *(((char *) pad)+iy+1) = (char) '\0';
+  }
+  if (strchr(pad, '"') == NULL) 
+    WriteOutFP (SKTfp, "\n  ! VAR_PADVALUE: \"%s\"", pad);
+  else if (strchr(pad, '\'') == NULL)
+    WriteOutFP (SKTfp, "\n  ! VAR_PADVALUE: '%s'", pad);
+  else
+    WriteOutFP (SKTfp, "\n  ! VAR_PADVALUE: $%s$", pad);
+} else {
+  char string[101], *format;
+  int  style;
+  if (TT2000dataType(varDataType)) style = TT2000_3_STYLE;
+  else style = EPOCH0_STYLE;
+  status = GetFormatEntry (zVar, varN, &format);
+  if (padValue == 1 && useFormat && format != NULL)
+    EncodeValue (varDataType, pad, string, style, 100);
+  else
+    EncodeValue (varDataType, pad, string, style, 100);
+    WriteOutFP (SKTfp, "\n  ! VAR_PADVALUE: %s", string);
+  if (format != NULL) cdf_FreeMemory (format, FatalError);
+}
+cdf_FreeMemory (pad, FatalError);
+
 CHECKforABORTso
 
 /***************************************************************************
@@ -1185,7 +1308,7 @@ long maxRec;
     }
   }
   value = cdf_AllocateMemory ((size_t) (numElements * CDFelemSize(dataType)),
-			  FatalError);
+			      FatalError);
   if (useFormat) {
     status = GetFormatEntry (zVar, varN, &format);
     if (!StatusHandlerC2S(status)) {
@@ -1204,6 +1327,7 @@ long maxRec;
        if (format != NULL) cdf_FreeMemory (format, FatalError);
        return FALSE;
      }
+     if (status == VIRTUAL_RECORD_DATA) continue;
      for (i = 0; i < nRecValues; i++) {
         status = CDFlib (SELECT_, BOO(zVar,zVAR_DIMINDICES_,
 				           rVARs_DIMINDICES_), indices,
@@ -1214,6 +1338,7 @@ long maxRec;
 	  if (format != NULL) cdf_FreeMemory (format, FatalError);
 	  return FALSE;
 	}
+        if (status == VIRTUAL_RECORD_DATA) break;
         ccc = WriteOut (fp, "\n    ");
 	if (recVary) {
 	  snprintf (tempS, (size_t) sizeof(tempS), "%ld:[", recN + 1);	  
@@ -1236,10 +1361,29 @@ long maxRec;
           WriteOut (fp, " }");
         }
         else {
-          EncodeValuesFormat (dataType, 1L, value, Evalue,
-/*			      format, 0, 0, style); */
-			      format, 0, (int) 80, style,
-			      (size_t) sizeof(Evalue));
+          if (useFormat && format != NULL) {
+            if ((dataType == CDF_FLOAT) || (dataType == CDF_REAL4)) {
+              if (!isnan((double)*(float *)value) &&
+                  *(float *)value <= DEFAULT_FLOAT_PADVALUE) {
+                EncodeValueFormat (dataType, value, Evalue, NULL, 0, 80,
+	 	                   style, (size_t) sizeof(Evalue));
+              } else 
+                EncodeValue (dataType, value, Evalue, style,
+                             (size_t) sizeof(Evalue));
+            } else if ((dataType == CDF_DOUBLE) || (dataType == CDF_REAL8)) {
+              if (!isnan(*(double *)value) &&
+                  *(double *)value <= DEFAULT_DOUBLE_PADVALUE) {
+                EncodeValueFormat (dataType, value, Evalue, NULL, 0, 80,
+	 	                   style, (size_t) sizeof(Evalue));
+              } else
+                EncodeValue (dataType, value, Evalue, style,
+                             (size_t) sizeof(Evalue));
+            } else
+              EncodeValueFormat (dataType, value, Evalue, format, 0, 80,
+	 	               style, (size_t) sizeof(Evalue));
+          } else
+            EncodeValue (dataType, value, Evalue, style,
+                         (size_t) sizeof(Evalue));
 						/* Don't care about width. */
           WriteOut (fp, Evalue);
         }
@@ -1497,7 +1641,7 @@ char **argV[];
 		*argC = 13 + BOO(NULpString(CDFtext),0,1) +
 			     	 BOO(NULpString(sktText),0,2) +
 			     	 BOO(NULpString(cacheText),0,2);
-    	*argV = (char **) cdf_AllocateMemory (*argC * sizeof(char *),
+    	*argV = (char **) cdf_AllocateMemory ((size_t)*argC * sizeof(char *),
 						  FatalError);
 		n = 0;
 		MAKEstrARGv (argV, n, pgmName)
@@ -1558,7 +1702,7 @@ char **argV[];
       case HELPin: {
         int n;
         *argC = 1;
-        *argV = (char **) cdf_AllocateMemory (*argC * sizeof(char *), FatalError);
+        *argV = (char **) cdf_AllocateMemory ((size_t)*argC * sizeof(char *), FatalError);
 		n = 0;
 		MAKEstrARGv (argV, n, pgmName)
 #ifdef __MWERKS__
