@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                                             CDFconvert.
 *
@@ -34,6 +39,8 @@
 *                               "tt20002epoch16" option to convert epoch from
 *                               CDF_EPOCH/CDF_EPOCH16 to CDF_TIME_TT2000 or 
 *                               from CDF_TIME_TT2000 to CDF_EPOCH/CDF_EPOCH16.
+*   V3.50 20-Sep-13, M Liu      For NRV variables, no compression is applied 
+*                               if the record size is < 1K.
 *
 ******************************************************************************/
 #include "cdfcvt.h"
@@ -656,17 +663,17 @@ char *dstPath;
   CHECKforABORTso
 
   if (!backward) {
-    if (checksumFlag == 0 || checksumFlag == 1) 	/* no or md5 */
+    if (checksumFlag == 0 || checksumFlag == 1) { 	/* no or md5 */
       status = CDFlib (SELECT_, CDF_, dstId,
                        PUT_, CDF_CHECKSUM_, checksum,
                        NULL_);
-    else if (checksumFlag == 2) 			/* source */
+    } else if (checksumFlag == 2) { 			/* source */
       if (srcChecksum != -999) {
         status = CDFlib (SELECT_, CDF_, dstId,
                          PUT_, CDF_CHECKSUM_, srcChecksum,
                          NULL_);
       }
-    else {					/* not specified */
+    } else {					/* not specified */
       int env = CDFgetChecksumEnvVar();
       if (env == 0) {  			/* env var not set ior set to no */
         if (srcChecksum != -999)
@@ -1060,7 +1067,7 @@ long DSTmajority;
 	sRecordsType, reservePct;
    char varName[CDF_VAR_NAME_LEN256 + 1]; long recNum, fromRec, toRec;
    int dimN; void *padValue; long nValuesPerRecord, nRecords;
-   Byte **handles[2], *buffer1, *buffer2;
+   Byte1 **handles[2], *buffer1, *buffer2;
    size_t nValueBytes[2]; long nHypers, nValues, hyperN;
    struct GroupStruct groups; struct HyperStruct hyper;
    Logical srcRowMajor = ROWmajor(SRCmajority), switchMajority;
@@ -1237,9 +1244,26 @@ long DSTmajority;
 		    PUT_, VAR_BLOCKINGFACTOR(Z), blockingFactor,
 			  VAR_SPARSERECORDS(Z), sRecordsType,
 			  VAR_SPARSEARRAYS(Z), sArraysType, sArraysParms,
-			  VAR_COMPRESSION(Z), cType, cParms,
+/*			  VAR_COMPRESSION(Z), cType, cParms, */
 		    NULL_);
    if (!StatusHandlerCvt("DST",status)) return FALSE;
+   if (!recVary) {
+     long values = 1, size;
+     for (dimN = 0; dimN < numDims; dimN++) values *= dimSizes[dimN];
+     status = CDFgetDataTypeSize (dataType, &size);
+     if ((size*values) >= 1024) { /* Allow compression if NRV record >= 1K */
+       status = CDFlib (PUT_, VAR_COMPRESSION(Z), cType, cParms,
+		        NULL_);
+     } else {
+       long cP[] = {0};
+       status = CDFlib (PUT_, VAR_COMPRESSION(Z), NO_COMPRESSION, cP,
+                        NULL_);
+       cType = NO_COMPRESSION;
+     }
+   } else
+     status = CDFlib (PUT_, VAR_COMPRESSION(Z), cType, cParms,
+		      NULL_);
+   if (!StatusHandlerCvt("DST",status)) return FALSE;
    if (cType != NO_COMPRESSION) {
      status = CDFlib (SELECT_, VAR_RESERVEPERCENT(Z), reservePct,
 		      NULL_);
@@ -1357,7 +1381,8 @@ long DSTmajority;
 	         } else {
 		   long count;
 		   int step = (dataType == CDF_EPOCH ? 1 : 2);
-		   bufferx = (long long *) cdf_AllocateMemory (values * 8,                                                                     FatalError);
+		   bufferx = (long long *) cdf_AllocateMemory ((size_t)values * 8,
+                                                               FatalError);
 		   if (bufferx == NULL) return FALSE;
 		   count = hyper.recCount;
 		   hyper.recCount = 1;
@@ -1386,7 +1411,7 @@ long DSTmajority;
                    cdf_FreeMemory (bufferx, NULL);
                    if (!StatusHandlerCvt("DST",status)) return FALSE;
                  } else {                   long count;
-                   bufferx = (double *) cdf_AllocateMemory (values * 8 * step,
+                   bufferx = (double *) cdf_AllocateMemory ((size_t)values * 8 * step,
                                                             FatalError);
                    if (bufferx == NULL) return FALSE;
                    count = hyper.recCount;
@@ -1422,7 +1447,7 @@ long DSTmajority;
           InitHyperParms (&hyper, &groups, numDims, &nHypers, &nValues);
 	  hyper.recNumber = fromRec;
           for (hyperN = 0; hyperN < nHypers; hyperN++) {
-             long indices[CDF_MAX_DIMS]; Byte *value = buffer1; long valueN;
+             long indices[CDF_MAX_DIMS]; Byte1 *value = buffer1; long valueN;
              status = HYPER_READ (srcId, Z, hyper, buffer1);
              if (!StatusHandlerCvt("SRC",status)) return FALSE;
              CHECKforABORTso
@@ -1526,7 +1551,7 @@ long DSTmajority;
                  if (!StatusHandlerCvt("DST",status)) return FALSE;
 	       } else {
 	         long count = hyper.recCount;
-	         bufferx = (long long *) cdf_AllocateMemory (values * 8,
+	         bufferx = (long long *) cdf_AllocateMemory ((size_t)values * 8,
                                                              FatalError);
 	         if (bufferx == NULL) return FALSE;
 	         hyper.recCount = 1;
@@ -1556,7 +1581,7 @@ long DSTmajority;
                  if (!StatusHandlerCvt("DST",status)) return FALSE;
                } else {
                  long count = hyper.recCount;
-                 bufferx = (double *) cdf_AllocateMemory (values * 8 * step,
+                 bufferx = (double *) cdf_AllocateMemory ((size_t)values * 8 * step,
                                                           FatalError);
                  if (bufferx == NULL) return FALSE;
                  hyper.recCount = 1;
@@ -1661,7 +1686,7 @@ char *options;
        *p2 = NUL;
        len = strlen (p1);
        if (len < 1) { BADs(S) }
-       Var->name = (char *) cdf_AllocateMemory (len, FatalError);
+       Var->name = (char *) cdf_AllocateMemory (len+1, FatalError);
        strcpyX (Var->name, p1, len);
        p2 += 1;
        if (*p2 != ':') { BADs(S) }
@@ -1794,7 +1819,7 @@ char *options;
        *p2 = NUL;
        len = strlen (p1);
        if (len < 1) { BADc(C) }
-       Var->name = (char *) cdf_AllocateMemory (len, FatalError);
+       Var->name = (char *) cdf_AllocateMemory ((size_t)len+1, FatalError);
        strcpyX (Var->name, p1, len);
        p2 += 1;
        if (*p2 != ':') { BADc(C) }
@@ -1889,15 +1914,6 @@ Logical *done;
        return TRUE;
      }
   }
-/*
-  if (strcmpIgCase(cToken,"zlib.0") == 1) {
-    *cType = ZLIB_COMPRESSION;
-    cParms[0] = ZLIB_OF_ZEROs;
-    ASSIGNnotNULL (bf, BOO(count > 0,v1,0))
-    ASSIGNnotNULL (reserve, BOO(count > 1,v2,0))
-    return TRUE;
-  }
-*/
   return FALSE;
 }
 
@@ -2202,7 +2218,7 @@ char **argV[];
 				     BOO(dstFormat != 0, 1, 0) +
 				     BOO(dstMajority != 0, 1, 0) +
 				     BOO(dstEncoding != 0, 2, 0);
-		*argV = (char **) cdf_AllocateMemory (*argC * sizeof(char *),
+		*argV = (char **) cdf_AllocateMemory ((size_t)*argC * sizeof(char *),
 										  FatalError);
 	
 		n = 0;
@@ -2293,7 +2309,7 @@ char **argV[];
       case HELPin: {
 		int n;
 		*argC = 1;
-		*argV = (char **) cdf_AllocateMemory (*argC * sizeof(char *),
+		*argV = (char **) cdf_AllocateMemory ((size_t)*argC * sizeof(char *),
 										  FatalError);
 		n = 0;
 		MAKEstrARGv (argV, n, pgmName)
