@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                                    CDFedit, auxiliary routines.
 *
@@ -152,7 +157,7 @@ va_dcl
        EW.nColsTotal = MaxInt (EW.nColsTotal, (int) (length + 2));
        textLength += length + 1;
     }
-    EW.eText = (char *) cdf_AllocateMemory (textLength + 1, FatalError);
+    EW.eText = (char *) cdf_AllocateMemory ((size_t)textLength + 1, FatalError);
     MakeNUL (EW.eText);
     for (lineN = 0; !NULstring(lineS[lineN]); lineN++) {
        strcatX (EW.eText, lineS[lineN], textLength);
