@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                                                    CDFinquire.
 *
@@ -246,15 +251,15 @@ void DisplayPadValueDefaults () {
   snprintf (text, (size_t) sizeof(text),
             "  CDF_INT8: ");
   snprintf (EofS(text), (size_t) sizeof(text)-strlen(text),
-            Int64FORMAT, (Int64) DEFAULT_INT8_PADVALUE);
+            Int64FORMAT, (long long) DEFAULT_INT8_PADVALUE);
   snprintf (EofS(text), (size_t) sizeof(text)-strlen(text),
             "\n");
   WriteOutSO (text);
   snprintf (text, (size_t) sizeof(text),
-	    "  CDF_UINT1: %u\n", (uInt) DEFAULT_UINT1_PADVALUE);
+	    "  CDF_UINT1: %u\n", (uInt4) DEFAULT_UINT1_PADVALUE);
   WriteOutSO (text);
   snprintf (text, (size_t) sizeof(text),
-	    "  CDF_UINT2: %u\n", (uInt) DEFAULT_UINT2_PADVALUE);
+	    "  CDF_UINT2: %u\n", (uInt4) DEFAULT_UINT2_PADVALUE);
   WriteOutSO (text);
   snprintf (text, (size_t) sizeof(text),
 	    "  CDF_UINT4: ");
@@ -264,22 +269,22 @@ void DisplayPadValueDefaults () {
 	    "\n");
   WriteOutSO (text);
   snprintf (text, (size_t) sizeof(text),
-	    "  CDF_REAL4: %f\n", (float) DEFAULT_REAL4_PADVALUE);
+	    "  CDF_REAL4: %g\n", (float) DEFAULT_REAL4_PADVALUE);
   WriteOutSO (text);
   snprintf (text, (size_t) sizeof(text),
-	    "  CDF_FLOAT: %f\n", (float) DEFAULT_FLOAT_PADVALUE);
+	    "  CDF_FLOAT: %g\n", (float) DEFAULT_FLOAT_PADVALUE);
   WriteOutSO (text);
   snprintf (text, (size_t) sizeof(text),
-	    "  CDF_REAL8: %f\n", (double) DEFAULT_REAL8_PADVALUE);
+	    "  CDF_REAL8: %g\n", (double) DEFAULT_REAL8_PADVALUE);
   WriteOutSO (text);
   snprintf (text, (size_t) sizeof(text),
-	    "  CDF_DOUBLE: %f\n", (double) DEFAULT_DOUBLE_PADVALUE);
+	    "  CDF_DOUBLE: %g\n", (double) DEFAULT_DOUBLE_PADVALUE);
   WriteOutSO (text);
   encodeEPOCH((double) DEFAULT_EPOCH_PADVALUE, epString);
   snprintf (text, (size_t) sizeof(text),
 	    "  CDF_EPOCH: %s\n", epString);
   WriteOutSO (text);
-  epoch16[0] = epoch16[1] = DEFAULT_EPOCH_PADVALUE;
+  epoch16[0] = epoch16[1] = DEFAULT_EPOCH16_PADVALUE;
   encodeEPOCH16(epoch16, epString16);
   snprintf (text, (size_t) sizeof(text),
 	    "  CDF_EPOCH16: %s\n", epString16);
@@ -321,12 +326,6 @@ void DisplayMiscDefaults () {
 	    "GZIP compression/decompression %s supported.\n",
 	   BOO((Logical)SUPPORT_GZIP,"is","is not"));
   WriteOutSO (text);
-/*
-  snprintf (text, (size_t) sizeof(text),
-	    "ZLIB compression/decompression %s supported.\n",
-	   BOO((Logical)SUPPORT_ZLIB64,"is","is not"));
-  WriteOutSO (text);
-*/
   WriteOutSO ("\n");
   snprintf (text, (size_t) sizeof(text),
 	    "MD5 checksum %s supported.\n",
@@ -648,6 +647,32 @@ void DisplayToolkitDefaults () {
   snprintf (text, (size_t) sizeof(text),
 	    "    -%spage\n", No(DEFAULTpageINQ));
   WriteOut (stdout, text);
+#endif
+  /****************************************************************************
+  * CDFdump.
+  ****************************************************************************/
+  WriteOut (stdout, "\n");
+  WriteOut (stdout, "  CDFdump\n");
+#if defined(vms)
+  snprintf (text, (size_t) sizeof(text),
+	    "    /%sFORMAT\n", No(DEFAULTformatDUMP));
+  WriteOut (stdout, text);
+  snprintf (text, (size_t) sizeof(text),
+	    "    /DUMP=ALL\n");
+  WriteOut (stdout, text);
+  snprintf (text, (size_t) sizeof(text),
+	    "    /%sHEADER\n", No(DEFAULTheaderDUMP));
+  WriteOut (stdout, text);
+#else
+  snprintf (text, (size_t) sizeof(text),
+	    "    -%sformat\n", No(DEFAULTformatDUMP));
+  WriteOut (stdout, text);
+  snprintf (text, (size_t) sizeof(text),
+	    "    -dump all\n");
+  WriteOut (stdout, text);
+  snprintf (text, (size_t) sizeof(text),
+	    "    -%sheader\n", No(DEFAULTheaderDUMP));
+  WriteOut (stdout, text);
 #endif
   /****************************************************************************
   * SkeletonCDF.
@@ -1227,7 +1252,7 @@ char **argV[];
 		* Build argc/argv.
 		**********************************************************************/
         *argC = 3;
-        *argV = (char **) cdf_AllocateMemory (*argC * sizeof(char *),
+        *argV = (char **) cdf_AllocateMemory ((size_t)*argC * sizeof(char *),
 					  FatalError);
 		n = 0;
 		MAKEstrARGv (argV, n, pgmName)
@@ -1249,7 +1274,7 @@ char **argV[];
       case HELPin: {
         int n;
         *argC = 1;
-        *argV = (char **) cdf_AllocateMemory (*argC * sizeof(char *),
+        *argV = (char **) cdf_AllocateMemory ((size_t)*argC * sizeof(char *),
 					  FatalError);
 		n = 0;
 		MAKEstrARGv (argV, n, pgmName)
