@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                                            CDFstats (statistics).
 *
@@ -782,7 +787,7 @@ char **argV[];
         *argC = 14 + BOO(NULpString(CDFtext),0,1) +
 		     BOO(NULpString(outText),0,2) +
 		     BOO(NULpString(cacheText),0,2);
-        *argV = (char **) cdf_AllocateMemory (*argC * sizeof(char *),
+        *argV = (char **) cdf_AllocateMemory ((size_t)*argC * sizeof(char *),
 					  FatalError);
 		n = 0;
 		MAKEstrARGv (argV, n, pgmName)
@@ -838,7 +843,7 @@ char **argV[];
       case HELPin: {
         int n;
         *argC = 1;
-        *argV = (char **) cdf_AllocateMemory (*argC * sizeof(char *), FatalError);
+        *argV = (char **) cdf_AllocateMemory ((size_t)*argC * sizeof(char *), FatalError);
 		n = 0;
 		MAKEstrARGv (argV, n, pgmName)
 		CloseDialog (dialogP);
