@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF							SkeletonCDF.
 *
@@ -28,6 +33,7 @@
 *   V1.5e 26-Jue-01, M Liu      Handle -delete option properly if no existing 
 *                               CDF.
 *   V2.0  19-May-05, M Liu      Allow space(s) in the CDF file name path.
+*   V3.3  04-Apr-11, M Liu      Modified to hanlde TT2000 epoch.
 ******************************************************************************/
 
 #include "skt2cdf.h"
@@ -57,6 +63,7 @@ Logical deleteIFexists;
 Logical useFillval;
 Logical negToPosFp0;
 Logical mLog;
+Logical warning;
 char line[MAX_SKTLINE_LEN+1+1];         /* + NL + NUL */
 int lineN;                              /* Line number in skeleton table. */
 char CDFpath[DU_MAX_PATH_LEN+1];
@@ -64,13 +71,16 @@ char *stream, *token, *string, *eValue, *location;
 size_t streamZ, tokenZ, stringZ, eValueZ, locationZ;
 char epoch[EPOCH_STRING_LEN+1];
 char epoch2[EPOCH16_STRING_LEN+1];
+char charStr[MAX_SKTLINE_LEN+1+1];
+char charDelimiter;
+int  delimiterNum, numDelimiters;
 Logical inString;
 char stringDelim;
 int stringLineN;
 Logical hyphenORendBraceNext;
 Logical startBraceFound;
 Logical locationStarted;
-int epochCount;
+int epochCount, charCount;
 int dimCount;
 int varyCount;
 enum searchForENUM searchFor;
@@ -99,6 +109,13 @@ static char selRIR[] = "selecting the current record/indices for rVariables";
 static char wriZ[] = "writing a zVariable value";
 static char wriR[] = "writing an rVariable value";
 static char cloCDF[] = "closing the CDF";
+static char cmpCDF[] = "compressing the CDF";
+static char cksCDF[] = "checksuming the CDF";
+static char libCDF[] = "reading the CDF library version";
+static char cmpVAR[] = "compressing the Variable";
+static char spaVAR[] = "setting the record sparseness for the Variable";
+static char blkVAR[] = "setting the blocking factor for the Variable";
+static char padVAR[] = "setting the pad value for the Variable";
 
 /******************************************************************************
 * Main.
@@ -140,13 +157,14 @@ char *argV[];
   static char *validQuals[] = {
     "cdf", "log", "nolog", "delete", "nodelete", "fillval", "nofillval",
     "report", "neg2posfp0", "noneg2posfp0", "about", "zmode", "statistics",
-    "nostatistics", "cache", NULL
+    "nostatistics", "cache", "warning", "nowarning", "backward", NULL
   };
   static int optRequired[] = {
     TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE,
-    TRUE, FALSE, FALSE, TRUE, 0
+    TRUE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE, 0
   };
   static char *reportTokens[] = { "errors", "warnings", "informationals" };
+
   /****************************************************************************
   * Parse qualifiers/options/parameters.
   ****************************************************************************/
@@ -183,9 +201,14 @@ char *argV[];
       /************************************************************************
       * Check for CDF pathname qualifier.
       ************************************************************************/
-      if (qop->qualEntered[CDFPATHqual])
+      if (qop->qualEntered[CDFPATHqual]) {
+	if (!ValidateQual(qop->qualOpt[CDFPATHqual], validQuals))
 		strcpyX (CDFpath, qop->qualOpt[CDFPATHqual], DU_MAX_PATH_LEN);
-      else
+	else {
+		DisplayError ("Invalid \"cdf\" qualifier.");
+		qopError = TRUE;
+	}
+       } else
 		CDFpath[0] = NUL;
       /************************************************************************
       * Check for `report' qualifier.  If absent, use defaults.
@@ -218,6 +241,9 @@ char *argV[];
       qopError = qopError | !TFqualifier(qop,&displayStats,STATSqual,
 					 NOSTATSqual,DEFAULTstatsSKT2CDF,
 					 "statistics");
+      qopError = qopError | !TFqualifier(qop,&warning,WARNINGqual,
+					 NOWARNINGqual,DEFAULTwarningSKT2CDF,
+					 "warning");
       /***********************************************************************
       * Check for `cache' qualifier.
       ***********************************************************************/
@@ -250,6 +276,12 @@ char *argV[];
       else
         zMode = DEFAULTzModeSKT2CDF;
       /************************************************************************
+      * Check for `backward' qualifier.
+      ************************************************************************/
+      if (qop->qualEntered[BACKWARDqual]) {
+        CDFsetFileBackward(BACKWARDFILEon);
+      }
+      /************************************************************************
       * Free QOP memory and check for an error.
       ************************************************************************/
       cdf_FreeMemory (qop, FatalError);
@@ -264,10 +296,23 @@ char *argV[];
   inString = FALSE;
   /****************************************************************************
   * Open skeleton table. Try several combinations for the skeleton table path.
+  * If the table file contains the ".skt" or ".SKT" extension, then uses it as
+  * is. Otherwise, appends ".skt", ".skeleton_table", ".SKT", ".skt;1" and
+  * ".SKT;1" to the table file in sequence to see if it exists. The last try
+  * is to use the table file name without extension after all preceeding
+  * combinations fail.
   ****************************************************************************/
   ExpandPath (SKTpath, SKTpathX);
-  SKTfp = fopen (SKTpathX, "r");
-  if (SKTfp == NULL) {
+  if (EndsWithIgCase(SKTpathX, ".skt") ||
+      EndsWithIgCase(SKTpathX, ".skt;1")) {
+    SKTfp = fopen (SKTpathX, "r");
+    if (SKTfp == NULL) {
+      WriteOut (stdout, "Unable to open skeleton table \"");
+      WriteOut (stdout, SKTpath);
+      WriteOut (stdout, "\".\n");
+      return FALSE;
+    }  
+  } else {
     strcatX (SKTpathX, ".skt", DU_MAX_PATH_LEN);
     SKTfp = fopen (SKTpathX, "r");
     if (SKTfp == NULL) {
@@ -287,10 +332,14 @@ char *argV[];
 	    strcatX (SKTpathX, ".SKT;1", DU_MAX_PATH_LEN);
 	    SKTfp = fopen (SKTpathX, "r");
 	    if (SKTfp == NULL) {
-	      WriteOut (stdout, "Unable to open skeleton table \"");
-	      WriteOut (stdout, SKTpath);
-	      WriteOut (stdout, "\".\n");
-	      return FALSE;
+	      ExpandPath (SKTpath, SKTpathX);
+	      SKTfp = fopen (SKTpathX, "r");
+	      if (SKTfp == NULL) {
+	        WriteOut (stdout, "Unable to open skeleton table \"");
+	        WriteOut (stdout, SKTpath);
+	        WriteOut (stdout, "\".\n");
+	        return FALSE;
+              }
             }
 	  }
 	}
@@ -299,13 +348,7 @@ char *argV[];
   }
   WriteOut (stdout, "Making a cdf from skeleton table: \"");
   WriteOut (stdout, SKTpathX);
-  if (!EndsWithIgCase(SKTpathX, ".skt"))
-    WriteOut (stdout, ".skt");
-  WriteOut (stdout, "\"  to  \"");
-/*
-  WriteOut (stdout, CDFpath);
-  WriteOut (stdout, "\"...\n");
-*/
+  WriteOut (stdout, "\"");
   /****************************************************************************
   * Open NRV file (may not exist).
   ****************************************************************************/
@@ -386,11 +429,25 @@ char *argV[];
 	     }
 	   }
 	   else {
-	     if (!CharStream((int)' ')) {
-	       FreeGrowingStrings ();
-	       return done;
+	     if (strstrIgCase(line, "cdf_compression") != NULL) {
+		NextSearchItem (TOKEN, CDFCOMPRESSIONmark);
+             } else if (strstrIgCase(line, "cdf_checksum") != NULL) {
+		NextSearchItem (TOKEN, CDFCHECKSUMmark);
+             } else if (strstrIgCase(line, "var_compression") != NULL) {
+		NextSearchItem (TOKEN, VARCOMPRESSIONmark);
+             } else if (strstrIgCase(line, "var_sparserecords") != NULL) {
+		NextSearchItem (TOKEN, VARSPARSEmark);
+             } else if (strstrIgCase(line, "var_blockingfactor") != NULL) {
+		NextSearchItem (TOKEN, VARBLOCKINGmark);
+             } else if (strstrIgCase(line, "var_padvalue") != NULL) {
+		NextSearchItem (TOKEN, VARPADVALUEmark);
+             } else { 
+	       if (!CharStream((int)' ')) {
+	         FreeGrowingStrings ();
+	         return done;
+	       }
+	       comment = TRUE;
 	     }
-	     comment = TRUE;
 	   }
 	   break;
 	 /*********************************************************************
@@ -626,6 +683,33 @@ int chr;
     /**************************************************************************
     *
     **************************************************************************/
+    case VARCHAR:
+      if (charCount == 0) {
+        if (!Spacing(chr)) {
+          int ii;
+          catchrX (charStr, chr, MAX_SKTLINE_LEN);
+          charCount = 1;
+          charDelimiter = chr;
+          numDelimiters = 0;
+          delimiterNum = 1;
+          for (ii = 0; ii < MAX_SKTLINE_LEN; ++ii) {
+            if (*(line+ii) == NUL) break;
+            if (*(line+ii) == chr) ++numDelimiters;
+          }
+        }
+      }
+      else {
+        catchrX (charStr, chr, MAX_SKTLINE_LEN);
+        charCount++;
+        if (chr == charDelimiter) ++delimiterNum;
+        if (charCount == MAX_SKTLINE_LEN ||
+            ((chr == charDelimiter) && (numDelimiters == delimiterNum)))
+          if (!ItemStream(charStr)) return FALSE;
+      }
+      break;
+    /**************************************************************************
+    *
+    **************************************************************************/
     default:
       ParseError ("** Internal error, contact CDFSUPPORT **");
       return FALSE;
@@ -905,6 +989,7 @@ char *item;
 		if (status != NO_SUCH_CDF )
 		  if (!StatusHandlerS2C(status,delCDF)) return FALSE;
 	    }
+	    WriteOut (stdout, "  to  \"");
 	    WriteOut (stdout, CDFpath);
 	    if (!EndsWithIgCase(CDFpath, ".cdf"))
 	      WriteOut (stdout, ".cdf");
@@ -944,6 +1029,7 @@ char *item;
 		if (status != NO_SUCH_CDF)
 		  if (!StatusHandlerS2C(status,delCDF)) return FALSE;
 	  }
+	  WriteOut (stdout, "  to  \"");
           WriteOut (stdout, CDFpath);
           if (!EndsWithIgCase(CDFpath, ".cdf"))
             WriteOut (stdout, ".cdf");
@@ -974,6 +1060,110 @@ char *item;
     /**************************************************************************
     *
     **************************************************************************/
+    case CDFCOMPRESSIONmark:
+      if (!strcmp(item,"CDF_COMPRESSION:"))
+        NextSearchItem (TOKEN, CDFCOMPRESSIONfield);
+      else
+        if (!strcmp(item,"CDF_COMPRESSION"))
+          NextSearchItem (TOKEN, CDFCOMPRESSIONCOLONmark);
+        else {
+          ItemError2 ("CDF_COMPRESSION:", "CDF_COMPRESSION", item);
+          return FALSE;
+        }
+      break;
+    /**************************************************************************
+    *
+    **************************************************************************/
+    case CDFCOMPRESSIONCOLONmark:
+      if (!strcmp(item,":"))
+	NextSearchItem (TOKEN, CDFCOMPRESSIONfield);
+      else {
+	ItemError1 (":", item);
+	return FALSE;
+      }
+      break;
+    /**************************************************************************
+    *
+    **************************************************************************/
+    case CDFCOMPRESSIONfield: {
+      long compression, compressionParms[CDF_MAX_PARMS];
+      long version, release, increment;
+      char cmpStr[MAX_SKTLINE_LEN+1+1];
+      strncpy(cmpStr, item, strlen(item));
+      cmpStr[strlen(item)] = (char) '\0';
+      compression = WhichCompression (cmpStr, &compression, compressionParms);
+      if (compression == -1) {
+	ItemError1 ("cdf<compression>", item);
+	return FALSE;
+      }
+      else
+	NextSearchItem (TOKEN, GATTRmark);
+      status = CDFlib (GET_, LIB_VERSION_, &version,
+                             LIB_RELEASE_, &release,
+                             LIB_INCREMENT_, &increment,
+                       NULL_);
+      if (!StatusHandlerS2C(status,libCDF)) return FALSE;
+      if (!PriorTo ("2.6.0", (Int32) version, (Int32) release,
+                    (Int32) increment)) {
+        status = CDFlib (PUT_, CDF_COMPRESSION_, compression, compressionParms,
+                         NULL_);
+        if (!StatusHandlerS2C(status,cmpCDF)) return FALSE; 
+      }
+      break;
+    }
+    /**************************************************************************
+    *
+    **************************************************************************/
+    case CDFCHECKSUMmark:
+      if (!strcmp(item,"CDF_CHECKSUM:"))
+        NextSearchItem (TOKEN, CDFCHECKSUMfield);
+      else
+        if (!strcmp(item,"CDF_CHECKSUM"))
+          NextSearchItem (TOKEN, CDFCHECKSUMCOLONmark);
+        else {
+          ItemError2 ("CDF_CHECKSUM:", "CDF_CHECKSUM", item);
+          return FALSE;
+        }
+      break;
+    /**************************************************************************
+    *
+    **************************************************************************/
+    case CDFCHECKSUMCOLONmark:
+      if (!strcmp(item,":"))
+	NextSearchItem (TOKEN, CDFCHECKSUMfield);
+      else {
+	ItemError1 (":", item);
+	return FALSE;
+      }
+      break;
+    /**************************************************************************
+    *
+    **************************************************************************/
+    case CDFCHECKSUMfield: {
+      long checksum, version, release, increment;
+      checksum = WhichChecksum (item);
+      if (checksum == -1) {
+	ItemError1 ("<checksum>", item);
+	return FALSE;
+      }
+      else
+	NextSearchItem (TOKEN, GATTRmark);
+      status = CDFlib (GET_, LIB_VERSION_, &version,
+                             LIB_RELEASE_, &release,
+                             LIB_INCREMENT_, &increment,
+                       NULL_);
+      if (!StatusHandlerS2C(status,libCDF)) return FALSE;
+      if (!PriorTo ("3.2.0", (Int32) version, (Int32) release,
+                    (Int32) increment)) {  
+        status = CDFlib (PUT_, CDF_CHECKSUM_, checksum,
+                         NULL_);
+        if (!StatusHandlerS2C(status,cksCDF)) return FALSE;
+      }
+      break;
+    }
+    /**************************************************************************
+    *
+    **************************************************************************/
     case GATTRmark:
       if (!strcmp(item,"#GLOBALattributes")) {
 	if (mLog)
@@ -1004,6 +1194,9 @@ char *item;
     case GaNAMEfield: {
       long gAttrNum;
       strcpyX (gAttrName, item, CDF_ATTR_NAME_LEN256);
+      if (!ISTPname (gAttrName) && warning)
+        WriteOutFP (stdout, "Warning: Attribute name: \"%s\" not ISTP compliant... not recommended\n",
+                    gAttrName);
       status = CDFlib (CREATE_, ATTR_, gAttrName, GLOBAL_SCOPE, &gAttrNum,
 		       NULL_);
       if (!StatusHandlerS2C(status,creG)) return FALSE;
@@ -1053,8 +1246,11 @@ char *item;
     case GaVALUEfield: {
       void *valuesB;
       long eNumElems;
+      int style;
       if (!STRINGdataType(eDataType)) {
-	if (!DecodeValues(item,eDataType,&eNumElems,&valuesB,EPOCH0_STYLE)) {
+        if (TT2000dataType(eDataType)) style = TT2000_3_STYLE;
+        else  style = EPOCH0_STYLE;
+	if (!DecodeValues(item,eDataType,&eNumElems,&valuesB,style)) {
 	  ParseError ("Illegal entry value(s).");
 	  return FALSE;
 	}
@@ -1131,6 +1327,9 @@ char *item;
     case VaNAMEfield: {
       long vAttrNum;
       strcpyX (vAttrName, item, CDF_ATTR_NAME_LEN256);
+      if (!ISTPname (vAttrName) && warning)
+        WriteOutFP (stdout, "Warning: Attribute name: \"%s\" not ISTP compliant... not recommended\n",
+                    vAttrName);
       status = CDFlib (CREATE_, ATTR_, vAttrName, VARIABLE_SCOPE, &vAttrNum,
 		       NULL_);
       if (!StatusHandlerS2C(status,creV)) return FALSE;
@@ -1249,8 +1448,8 @@ char *item;
     case VARRECVARYfield:
       if (strlen(item) > (size_t) 1) {
 	char msg[MAX_MSG_LEN+1];
-	sprintf (msg, "Extra character(s) after record variance (`%s').",
-		 &item[1]);
+	snprintf (msg, (size_t) sizeof(msg),
+		  "Extra character(s) after record variance (`%s').", &item[1]);
 	ParseError (msg);
 	return FALSE;
       }
@@ -1272,6 +1471,9 @@ char *item;
 	}
 	else {
 	  zVar = BOO(zSection,TRUE,(zMode > zMODEoff));
+          if (!ISTPname (varName) && warning)
+            WriteOutFP (stdout, "Warning: Variable name: \"%s\" not ISTP compliant... not recommended\n",
+                        varName);
 	  if (zVar)
 	    status = CDFlib (CREATE_, zVAR_, varName, vDataType, vNumElems,
 					     0L, NULL, recVary, NULL, &varNum,
@@ -1316,8 +1518,9 @@ char *item;
     case VARDIMVARYfield:
       if (strlen(item) > (size_t) 1) {
 	char msg[MAX_MSG_LEN+1];
-	sprintf (msg, "Extra character(s) after dimension variance (`%s').",
-		 &item[1]);
+	snprintf (msg, (size_t) sizeof(msg),
+		  "Extra character(s) after dimension variance (`%s').",
+		  &item[1]);
 	ParseError (msg);
 	return FALSE;
       }
@@ -1445,8 +1648,11 @@ char *item;
     case VaeVALUEfield: {
       void *eValueB;
       long eNumElems;
+      int style;
       if (!STRINGdataType(eDataType)) {
-	if (!DecodeValues(item,eDataType,&eNumElems,&eValueB,EPOCH0_STYLE)) {
+        if (TT2000dataType(eDataType)) style = TT2000_3_STYLE;
+        else style = EPOCH0_STYLE;
+	if (!DecodeValues(item,eDataType,&eNumElems,&eValueB,style)) {
 	  ParseError ("Illegal entry value(s).");
 	  return FALSE;
 	}
@@ -1589,11 +1795,242 @@ char *item;
     /**************************************************************************
     *
     **************************************************************************/
+    case VARCOMPRESSIONmark:
+      if (!strcmp(item,"VAR_COMPRESSION:"))
+        NextSearchItem (TOKEN, VARCOMPRESSIONfield);
+      else
+        if (!strcmp(item,"VAR_COMPRESSION"))
+          NextSearchItem (TOKEN, VARCOMPRESSIONCOLONmark);
+        else {
+          ItemError2 ("VAR_COMPRESSION:", "VAR_COMPRESSION", item);
+          return FALSE;
+        }
+      break;
+    /**************************************************************************
+    *
+    **************************************************************************/
+    case VARCOMPRESSIONCOLONmark:
+      if (!strcmp(item,":"))
+	NextSearchItem (TOKEN, VARCOMPRESSIONfield);
+      else {
+	ItemError1 (":", item);
+	return FALSE;
+      }
+      break;
+    /**************************************************************************
+    *
+    **************************************************************************/
+    case VARCOMPRESSIONfield: {
+      long compression, compressionParms[CDF_MAX_PARMS];
+      long version, release, increment;
+      char cmpStr[MAX_SKTLINE_LEN+1+1];
+      strncpy(cmpStr, item, strlen(item));
+      cmpStr[strlen(item)] = (char) '\0';
+      compression = WhichCompression (cmpStr, &compression, compressionParms);
+      if (compression == -1) {
+	ItemError1 ("<varcompression>", item);
+	return FALSE;
+      }
+      else
+	NextSearchItem (TOKEN, VaNAMEfieldOrPERIODmark);
+      status = CDFlib (GET_, LIB_VERSION_, &version,
+                             LIB_RELEASE_, &release,
+                             LIB_INCREMENT_, &increment,
+                       NULL_);
+      if (!StatusHandlerS2C(status,libCDF)) return FALSE;
+      if (!PriorTo ("2.6.0", (Int32) version, (Int32) release,
+                    (Int32) increment)) {
+        zVar = BOO(zSection,TRUE,(zMode > zMODEoff));
+        status = CDFlib (PUT_, VAR_COMPRESSION(zVar), compression,
+                                                      compressionParms,
+                         NULL_);
+        if (!StatusHandlerS2C(status,cmpVAR)) return FALSE; 
+      }
+      break;
+    }
+    /**************************************************************************
+    *
+    **************************************************************************/
+    case VARSPARSEmark:
+      if (!strcmp(item,"VAR_SPARSERECORDS:"))
+        NextSearchItem (TOKEN, VARSPARSEfield);
+      else
+        if (!strcmp(item,"VAR_SPARSERECORDS"))
+          NextSearchItem (TOKEN, VARSPARSECOLONmark);
+        else {
+          ItemError2 ("VAR_SPARSERECORDS:", "VAR_SPARSERECORDS", item);
+          return FALSE;
+        }
+      break;
+    /**************************************************************************
+    *
+    **************************************************************************/
+    case VARSPARSECOLONmark:
+      if (!strcmp(item,":"))
+	NextSearchItem (TOKEN, VARSPARSEfield);
+      else {
+	ItemError1 (":", item);
+	return FALSE;
+      }
+      break;
+    /**************************************************************************
+    *
+    **************************************************************************/
+    case VARSPARSEfield: {
+      long sparse;
+      sparse = WhichRecSparseness (item);
+      if (sparse == -1) {
+	ItemError1 ("<var_sparserecords>", item);
+	return FALSE;
+      }
+      else
+	NextSearchItem (TOKEN, VaNAMEfieldOrPERIODmark);
+      zVar = BOO(zSection,TRUE,(zMode > zMODEoff));
+      if (recVary == NOVARY) break;
+      status = CDFlib (PUT_, VAR_SPARSERECORDS(zVar), sparse,
+                       NULL_);
+      if (!StatusHandlerS2C(status,spaVAR)) return FALSE; 
+      break;
+    }
+    /**************************************************************************
+    *
+    **************************************************************************/
+    case VARBLOCKINGmark:
+      if (!strcmp(item,"VAR_BLOCKINGFACTOR:"))
+        NextSearchItem (TOKEN, VARBLOCKINGfield);
+      else
+        if (!strcmp(item,"VAR_BLOCKINGFACTOR"))
+          NextSearchItem (TOKEN, VARBLOCKINGCOLONmark);
+        else {
+          ItemError2 ("VAR_BLOCKINGFACTOR:", "VAR_BLOCKINGFACTOR", item);
+          return FALSE;
+        }
+      break;
+    /**************************************************************************
+    *
+    **************************************************************************/
+    case VARBLOCKINGCOLONmark:
+      if (!strcmp(item,":"))
+	NextSearchItem (TOKEN, VARBLOCKINGfield);
+      else {
+	ItemError1 (":", item);
+	return FALSE;
+      }
+      break;
+    /**************************************************************************
+    *
+    **************************************************************************/
+    case VARBLOCKINGfield: {
+      long bf;
+      if (sscanf(item, "%ld", &bf) != 1) {
+	ItemError1 ("<var_blockingfactor>", item);
+	return FALSE;
+      }
+      else
+	NextSearchItem (TOKEN, VaNAMEfieldOrPERIODmark);
+      zVar = BOO(zSection,TRUE,(zMode > zMODEoff));
+      status = CDFlib (PUT_, VAR_BLOCKINGFACTOR(zVar), bf,
+                       NULL_);
+      if (!StatusHandlerS2C(status,spaVAR)) return FALSE; 
+      break;
+    }
+    /**************************************************************************
+    *
+    **************************************************************************/
+    case VARPADVALUEmark:
+      if (!strcmp(item,"VAR_PADVALUE:")) {
+        if (vDataType == CDF_EPOCH)
+	  NextSearchItem (VAREPOCH, VARPADVALUEfield);
+        else if (vDataType == CDF_EPOCH16)
+          NextSearchItem (VAREPOCH16, VARPADVALUEfield);
+        else if (vDataType == CDF_CHAR || vDataType == CDF_UCHAR)
+          NextSearchItem (VARCHAR, VARPADVALUEfield);
+        else
+          NextSearchItem (TOKEN, VARPADVALUEfield);
+      } else {
+        if (!strcmp(item,"VAR_PADVALUE")) {
+          if (vDataType == CDF_EPOCH)
+            NextSearchItem (VAREPOCH, VARPADVALUEfield);
+          else if (vDataType == CDF_EPOCH16)
+            NextSearchItem (VAREPOCH16, VARPADVALUEfield);
+          else if (vDataType == CDF_CHAR || vDataType == CDF_UCHAR)
+            NextSearchItem (VARCHAR, VARPADVALUEfield);
+          else
+            NextSearchItem (TOKEN, VARPADVALUEmark);
+        } else {
+          ItemError2 ("VAR_PADVALUE:", "VAR_PADVALUE", item);
+          return FALSE;
+        }
+      }
+      break;
+    /**************************************************************************
+    *
+    **************************************************************************/
+    case VARPADVALUECOLONmark:
+      if (!strcmp(item,":"))
+	NextSearchItem (TOKEN, VARPADVALUEfield);
+      else {
+	ItemError1 (":", item);
+	return FALSE;
+      }
+      break;
+    /**************************************************************************
+    *
+    **************************************************************************/
+    case VARPADVALUEfield: {
+      void *valuesB;
+      long pNumElems;
+      int style;
+      if (!STRINGdataType(vDataType)) {
+        if (TT2000dataType(vDataType)) style = TT2000_3_STYLE;
+        else  style = EPOCH0_STYLE;
+        if (!DecodeValues(item,vDataType,&pNumElems,&valuesB,style)) {
+          ParseError ("Illegal pad value.");
+          return FALSE;
+        }
+        if (pNumElems != 1) {
+          ParseError ("Illegal number of elements for a pad value.");
+          cdf_FreeMemory (valuesB, FatalError);
+          return FALSE;
+        }
+        zVar = BOO(zSection,TRUE,(zMode > zMODEoff));
+        status = CDFlib (PUT_, VAR_PADVALUE(zVar), valuesB,
+                         NULL_);
+      }
+      else {
+        int len;
+        char *tmp;
+        valuesB = item + 1;
+        tmp = cdf_AllocateMemory (vNumElems + 1, FatalError);
+        strncpy (tmp, valuesB, (size_t) vNumElems);
+        *(tmp+vNumElems) = '\0';
+        len = (int) strlen (valuesB);
+        if ((len-1) < vNumElems) {
+          int ix;
+          for (ix = (len-1); ix < vNumElems; ++ix) *(tmp+ix) = (char) ' ';
+        }
+        zVar = BOO(zSection,TRUE,(zMode > zMODEoff));
+        status = CDFlib (PUT_, VAR_PADVALUE(zVar), tmp,
+                         NULL_);
+        if (strchr(tmp, '"') != NULL) inString = FALSE;
+        cdf_FreeMemory (tmp, FatalError);
+      }
+      if (!StatusHandlerS2C(status,padVAR)) return FALSE;
+      if (!STRINGdataType(vDataType)) cdf_FreeMemory (valuesB, FatalError);
+      NextSearchItem (TOKEN, VaNAMEfieldOrPERIODmark);
+      break;
+    }
+    /**************************************************************************
+    *
+    **************************************************************************/
     case VARVALUEfield: {
       void *value;
       long numElems;
+      int style;
       if (!STRINGdataType(vDataType)) {
-	if (!DecodeValues(item,vDataType,&numElems,&value,EPOCH0_STYLE)) {
+        if (TT2000dataType(vDataType)) style = TT2000_3_STYLE;
+        else style = EPOCH0_STYLE;
+	if (!DecodeValues(item,vDataType,&numElems,&value,style)) {
 	  ParseError ("Illegal variable value.\n");
 	  return FALSE;
 	}
@@ -1611,8 +2048,8 @@ char *item;
 	  WriteOut (stdout, "ERROR: Truncating value for variable `");
 	  WriteOut (stdout, varName);
 	  WriteOut (stdout, "' at line\n");
-	  sprintf (tempS, "       number %d (this is a non-fatal error).\n",
-		   lineN);
+	  snprintf (tempS, (size_t) sizeof(tempS),
+		    "       number %d (this is a non-fatal error).\n", lineN);
 	  WriteOut (stdout, tempS);
 	  value = item;
 	}
@@ -1624,7 +2061,8 @@ char *item;
 			"WARNING: Blank padding value for variable `");
 	      WriteOut (stdout, varName);
 	      WriteOut (stdout, "'\n");
-	      sprintf (tempS, "         at line number %d.\n", lineN);
+	      snprintf (tempS, (size_t) sizeof(tempS),
+			"         at line number %d.\n", lineN);
 	      WriteOut (stdout, tempS);
 	    }
 	    nBytes = (size_t) (vNumElems + 1);
@@ -1697,6 +2135,10 @@ enum nextItemENUM item;
       epochCount = 0;
       epoch2[0] = NUL;
       break;
+    case VARCHAR:
+      charCount = 0;
+      charStr[0] = NUL;
+      break;
   }
   nextItem = item;
   stream[0] = NUL;
@@ -1712,7 +2154,8 @@ char *expected;
 char *found;
 {
   char msg[MAX_MSG_LEN+1];
-  sprintf (msg, "Expecting `%s', found `%s' instead.", expected, found);
+  snprintf (msg, (size_t) sizeof(msg),
+	    "\nExpecting `%s', found `%s' instead.", expected, found);
   ParseError (msg);
   return;
 }
@@ -1727,8 +2170,9 @@ char *expected2;
 char *found;
 {
   char msg[MAX_MSG_LEN+1];
-  sprintf (msg, "Expecting `%s' or `%s', found `%s' instead.",
-	   expected1, expected2, found);
+  snprintf (msg, (size_t) sizeof(msg),
+	    "Expecting `%s' or `%s', found `%s' instead.",
+	    expected1, expected2, found);
   ParseError (msg);
   return;
 }
@@ -1744,8 +2188,9 @@ char *expected3;
 char *found;
 {
   char msg[MAX_MSG_LEN+1];
-  sprintf (msg, "Expecting `%s', `%s', or `%s', found `%s' instead.",
-	   expected1, expected2, expected3, found);
+  snprintf (msg, (size_t) sizeof(msg),
+	    "Expecting `%s', `%s', or `%s', found `%s' instead.",
+	    expected1, expected2, expected3, found);
   ParseError (msg);
   return;
 }
@@ -1760,8 +2205,9 @@ char *msg;
   char tempS[MAX_MSG_LEN+1];
   WriteOut (stdout, msg);
   WriteOut (stdout, "\n\n");
-  sprintf (tempS, "Error at (or before) line number %d which follows...\n\n",
-	   lineN);
+  snprintf (tempS, (size_t) sizeof(tempS),
+	    "Error at (or before) line number %d which follows...\n\n",
+	    lineN);
   WriteOut (stdout, tempS);
   WriteOut (stdout, line);
   WriteOut (stdout, "\n");      /* `line' has a NL at the end already. */
@@ -1893,9 +2339,9 @@ char *msg;
     CDFlib (SELECT_, CDF_STATUS_, status,
 	    GET_, STATUS_TEXT_, text,
 	    NULL_);
-    sprintf (tempS, "\n%s%s%s.\n\n%s\n", infoT,
-	     ((strlen(infoT) + strlen(msg) + 2 >
-	      (size_t) MAX_SCREENLINE_LEN) ? "\n" : " "), msg, text);
+    snprintf (tempS, (size_t) sizeof(tempS), "\n%s%s%s.\n\n%s\n", infoT,
+	      ((strlen(infoT) + strlen(msg) + 2 >
+	       (size_t) MAX_SCREENLINE_LEN) ? "\n" : " "), msg, text);
     WriteOut (stdout, tempS);
     return TRUE;
   }
@@ -1903,9 +2349,9 @@ char *msg;
     CDFlib (SELECT_, CDF_STATUS_, status,
 	    GET_, STATUS_TEXT_, text,
 	    NULL_);
-    sprintf (tempS, "\n%s%s%s.\n\n%s\n", warnT,
-	     ((strlen(warnT) + strlen(msg) + 2 >
-	      (size_t) MAX_SCREENLINE_LEN) ? "\n" : " "), msg, text);
+    snprintf (tempS, (size_t) sizeof(tempS), "\n%s%s%s.\n\n%s\n", warnT,
+	      ((strlen(warnT) + strlen(msg) + 2 >
+	       (size_t) MAX_SCREENLINE_LEN) ? "\n" : " "), msg, text);
     WriteOut (stdout, tempS);
     return TRUE;
   }
@@ -1914,9 +2360,9 @@ char *msg;
       CDFlib (SELECT_, CDF_STATUS_, status,
 	      GET_, STATUS_TEXT_, text,
 	      NULL_);
-      sprintf (tempS, "\n%s%s%s.\n\n%s\n", errorT,
-	       ((strlen(errorT) + strlen(msg) + 2 >
-		(size_t) MAX_SCREENLINE_LEN) ? "\n" : " "), msg, text);
+      snprintf (tempS, (size_t) sizeof(tempS), "\n%s%s%s.\n\n%s\n", errorT,
+	        ((strlen(errorT) + strlen(msg) + 2 >
+		 (size_t) MAX_SCREENLINE_LEN) ? "\n" : " "), msg, text);
       WriteOut (stdout, tempS);
     }
     ParseError ("");
