@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                                            Windowing functions.
 *
@@ -206,7 +211,7 @@ int rendition;
 #if defined(SMGui)
   long rowN = row + 1;
   long colN = col + 1;
-  uLong rend = RenditionMapping (rendition);
+  uLongx rend = RenditionMapping (rendition);
   if (StatusBad(smg$change_rendition(&(wid->id),&rowN,&colN,
 				     &num_rows,&num_cols,&rend))) return FALSE;
   return TRUE;
@@ -277,13 +282,13 @@ int create_pasteboard () {
   cursorWIND = NULL;
   cursorVisible = FALSE;
   cursorOn = FALSE;
-  pbCurrentChars = (char *) cdf_AllocateMemory (nChars, FatalError);
-  pbCurrentAttrs = (char *) cdf_AllocateMemory (nChars, FatalError);
-  pbNewChars = (char *) cdf_AllocateMemory (nChars, FatalError);
-  pbNewAttrs = (char *) cdf_AllocateMemory (nChars, FatalError);
-  pbNullChars = (char *) cdf_AllocateMemory (nChars, FatalError);
-  pbBlankChars = (char *) cdf_AllocateMemory (nChars, FatalError);
-  pbNormalAttrs = (char *) cdf_AllocateMemory (nChars, FatalError);
+  pbCurrentChars = (char *) cdf_AllocateMemory ((size_t)nChars, FatalError);
+  pbCurrentAttrs = (char *) cdf_AllocateMemory ((size_t)nChars, FatalError);
+  pbNewChars = (char *) cdf_AllocateMemory ((size_t)nChars, FatalError);
+  pbNewAttrs = (char *) cdf_AllocateMemory ((size_t)nChars, FatalError);
+  pbNullChars = (char *) cdf_AllocateMemory ((size_t)nChars, FatalError);
+  pbBlankChars = (char *) cdf_AllocateMemory ((size_t)nChars, FatalError);
+  pbNormalAttrs = (char *) cdf_AllocateMemory ((size_t)nChars, FatalError);
   for (charN = 0; charN < nChars; charN++) {
      pbNullChars[charN] = 0;
      pbBlankChars[charN] = ' ';
@@ -318,8 +323,8 @@ int rendition;			/* Rendition of border (if bordered). */
 {
 #if defined(SMGui)
   LocalId id;
-  uLong attrs = 0;
-  uLong rend = RenditionMapping (NORMAL);   /* Default for display. */
+  uLongx attrs = 0;
+  uLongx rend = RenditionMapping (NORMAL);   /* Default for display. */
   long nRows = num_rows;
   long nCols = num_cols;
   if (StatusBad(smg$create_virtual_display(&nRows,&nCols,&id,
@@ -344,13 +349,13 @@ int rendition;			/* Rendition of border (if bordered). */
   int nChars = num_rows * num_cols;
   if (num_rows < 1 || num_rows > NUMfsiROWS) return FALSE;
   if (num_cols < 1 || num_cols > NUMfsiCOLS) return FALSE;
-  id = (LocalId) cdf_AllocateMemory (sizeof(COWvd), FatalError);
+  id = (LocalId) cdf_AllocateMemory ((size_t)sizeof(COWvd), FatalError);
   id->nRows = num_rows;
   id->nCols = num_cols;
   id->atRowN = 0;
   id->atColN = 0;
-  id->chars = (char *) cdf_AllocateMemory (nChars, FatalError);
-  id->attrs = (char *) cdf_AllocateMemory (nChars, FatalError);
+  id->chars = (char *) cdf_AllocateMemory ((size_t)nChars, FatalError);
+  id->attrs = (char *) cdf_AllocateMemory ((size_t)nChars, FatalError);
   *wid = AddWIND (id, FALSE, (borderMode == BORDER));
   memmove (id->chars, pbBlankChars, nChars);
   memmove (id->attrs, pbNormalAttrs, nChars);
@@ -368,7 +373,7 @@ int delete_pasteboard (eraseMode)
 int eraseMode;
 {
 #if defined(SMGui)
-  uLong flags = (eraseMode == ERASE ? SMG$M_ERASE_PBD : 0);
+  uLongx flags = (eraseMode == ERASE ? SMG$M_ERASE_PBD : 0);
   Logical status = DeleteWINDs();
   if (StatusBad(smg$delete_pasteboard(&pbid,&flags))) return FALSE;
   return status;
@@ -438,7 +443,7 @@ Logical teeEnds;	/* If TRUE, draw ACS_LTEE and ACS_RTEE at the ends of
   long endRowN = startRowN;
   long startColN = LcolN + 1;
   long endColN = RcolN + 1;
-  uLong rend = RenditionMapping(rendition);
+  uLongx rend = RenditionMapping(rendition);
   if (StatusBad(smg$draw_line(&(wid->id),&startRowN,&startColN,
 			      &endRowN,&endColN,&rend,NULL))) return FALSE;
 #endif
@@ -498,7 +503,7 @@ Logical teeEnds;	/* If TRUE, draw ACS_TTEE and ACS_BTEE at the ends of
   long endRowN = BrowN + 1;
   long startColN = colN + 1;
   long endColN = startColN;
-  uLong rend = RenditionMapping(rendition);
+  uLongx rend = RenditionMapping(rendition);
   if (StatusBad(smg$draw_line(&(wid->id),&startRowN,&startColN,
 			      &endRowN,&endColN,&rend,NULL))) return FALSE;
 #endif
@@ -552,7 +557,7 @@ int rendition;		/* Video attributes. */
   long startCol = Lcol + 1;
   long endRow = Brow + 1;
   long endCol = Rcol + 1;
-  uLong rend = RenditionMapping (rendition);
+  uLongx rend = RenditionMapping (rendition);
   if (StatusBad(smg$draw_rectangle(&(wid->id),&startRow,&startCol,
 				   &endRow,&endCol,&rend,NULL))) return FALSE;
   return TRUE;
@@ -928,8 +933,8 @@ int rendition;
 #if defined(SMGui)
   int len = (int) strlen(label);
   static struct dsc$descriptor_s descr = {0,DSC$K_DTYPE_T,DSC$K_CLASS_S,NULL};
-  uLong position = SMG$K_TOP;
-  uLong rend = RenditionMapping(rendition);
+  uLongx position = SMG$K_TOP;
+  uLongx rend = RenditionMapping(rendition);
   int nRows, nCols;
   long startRow = 1;
   long startCol;
@@ -1030,7 +1035,7 @@ int rendition;
 {
 #if defined(SMGui)
   static struct dsc$descriptor_s descr = {0,DSC$K_DTYPE_T,DSC$K_CLASS_S,NULL};
-  uLong rend = RenditionMapping (rendition);
+  uLongx rend = RenditionMapping (rendition);
   long rowN = row + 1;
   long colN = col + 1;
   if (eraseMode == ERASE) {
@@ -1099,7 +1104,7 @@ char *string;
   static struct dsc$descriptor_s descr = {0,DSC$K_DTYPE_T,DSC$K_CLASS_S,NULL};
   int nRows, nCols; long rowN = row + 1; char *stringT;
   WindowSize (wid->id, &nRows, &nCols);
-  stringT = (char *) cdf_AllocateMemory (nCols, FatalError);
+  stringT = (char *) cdf_AllocateMemory ((size_t)nCols, FatalError);
   descr.dsc$w_length = nCols;
   descr.dsc$a_pointer = stringT;
   if (StatusBad(smg$read_from_display(&(wid->id),&descr,NULL,&rowN))) {
@@ -1237,6 +1242,9 @@ Logical block;		/* Block until key available? */
 #if defined(__CYGWIN__)
     case CYGWIN_DELETE: *tcode = KB_DELETE; break;
 #endif
+#if defined(linux)
+    case LINUX_DELETE: *tcode = KB_DELETE; break;
+#endif
 #if defined(__MINGW32__)
     case MINGW32_DELETE: *tcode = KB_DELETE; break;
 #endif
@@ -1595,7 +1603,7 @@ int set_cursor_mode (cursorMode)
 int cursorMode;                         /* CURSORon/CURSORoff */
 {
 #if defined(SMGui)
-  uLong mode = (cursorMode == CURSORon ? SMG$M_CURSOR_ON :
+  uLongx mode = (cursorMode == CURSORon ? SMG$M_CURSOR_ON :
 						 SMG$M_CURSOR_OFF);
   if (StatusBad(smg$set_cursor_mode(&pbid,&mode))) return FALSE;
   cursorOn = (cursorMode == CURSORon);
@@ -1756,7 +1764,7 @@ Logical pasted;
 Logical bordered;
 {
   WINDOWid newWIND, tW;
-  newWIND = (WINDOWid) cdf_AllocateMemory (sizeof(WIND), FatalError);
+  newWIND = (WINDOWid) cdf_AllocateMemory ((size_t)sizeof(WIND), FatalError);
   if (WINDhead == NULL)
     WINDhead = newWIND;
   else {
@@ -1871,7 +1879,7 @@ static Logical DeleteWINDs () {
 static Logical RefreshWINDs (level)
 int level;
 {
-  if (batchCount < 1) {
+/*  if (batchCount < 1) { */
     WINDOWid tW;
     switch (level) {
       case HARD_:
@@ -1889,7 +1897,7 @@ int level;
       tW = tW->next;
     }
     doupdate ();
-  }
+/*  } */
   return TRUE;
 }
 #endif
